@@ -23,12 +23,14 @@
 #include <unistd.h>
 
 #include <qapplication.h>
-#include <rddb.h>
-#include <rd.h>
-#include <dbversion.h>
-#include <panel_copy.h>
-#include <rdcmd_switch.h>
 
+#include <dbversion.h>
+#include <rd.h>
+#include <rdcmd_switch.h>
+#include <rddb.h>
+#include <rdescape_string.h>
+
+#include "panel_copy.h"
 
 MainObject::MainObject(QObject *parent)
   : QObject(parent)
@@ -39,8 +41,8 @@ MainObject::MainObject(QObject *parent)
   QString src_station;
   QString dest_station;
   QString sql;
-  RDSqlQuery *q;
-  RDSqlQuery *q1;
+  QSqlQuery *q;
+  QSqlQuery *q1;
 
   //
   // Read Command Options
@@ -98,44 +100,33 @@ MainObject::MainObject(QObject *parent)
   // Open Databases
   //
   src_db=QSqlDatabase::addDatabase("QMYSQL3","SRCDB");
-  if(!src_db) {
-    fprintf(stderr,"panel_copy: can't open source mySQL database\n");
-    exit(1);
-  }
-  src_db->setDatabaseName(rd_config->mysqlDbname());
-  src_db->setUserName(rd_config->mysqlUsername());
-  src_db->setPassword(rd_config->mysqlPassword());
-  src_db->setHostName(src_hostname);
-  if(!src_db->open()) {
+  src_db.setDatabaseName(rd_config->mysqlDbname());
+  src_db.setUserName(rd_config->mysqlUsername());
+  src_db.setPassword(rd_config->mysqlPassword());
+  src_db.setHostName(src_hostname);
+  if(!src_db.open()) {
     fprintf(stderr,"panel_copy: unable to connect to source mySQL server\n");
-    src_db->removeDatabase(rd_config->mysqlDbname());
-    exit(256);
+    exit(1);
   }
 
   dest_db=QSqlDatabase::addDatabase("QMYSQL3","DESTDB");
-  if(!dest_db) {
-    fprintf(stderr,"panel_copy: can't open destination mySQL database\n");
-    exit(1);
-  }
-  dest_db->setDatabaseName(rd_config->mysqlDbname());
-  dest_db->setUserName(rd_config->mysqlUsername());
-  dest_db->setPassword(rd_config->mysqlPassword());
-  dest_db->setHostName(dest_hostname);
-  if(!dest_db->open()) {
+  dest_db.setDatabaseName(rd_config->mysqlDbname());
+  dest_db.setUserName(rd_config->mysqlUsername());
+  dest_db.setPassword(rd_config->mysqlPassword());
+  dest_db.setHostName(dest_hostname);
+  if(!dest_db.open()) {
     fprintf(stderr,
 	    "panel_copy: unable to connect to destination mySQL server\n");
-    dest_db->removeDatabase(rd_config->mysqlDbname());
-    exit(256);
+    exit(1);
   }
 
   //
   // Check Database Versions
   //
-  sql="select DB from VERSION";
-  q=new RDSqlQuery(sql,src_db);
+  sql=QString("select DB from VERSION");
+  q=new QSqlQuery(sql,src_db);
   if(!q->first()) {
-    fprintf(stderr,
-	    "panel_copy: unable to read source database version\n");
+    fprintf(stderr,"panel_copy: unable to read source database version\n");
     exit(256);
   }
   if(q->value(0).toInt()!=RD_VERSION_DATABASE) {
@@ -144,7 +135,7 @@ MainObject::MainObject(QObject *parent)
   }
   delete q;
 
-  q=new RDSqlQuery(sql,dest_db);
+  q=new QSqlQuery(sql,dest_db);
   if(!q->first()) {
     fprintf(stderr,
 	    "panel_copy: unable to read destination database version\n");
@@ -172,34 +163,34 @@ MainObject::MainObject(QObject *parent)
   // Delete current destination entries
   //
   sql="delete from PANELS";
-  q=new RDSqlQuery(sql,dest_db);
+  q=new QSqlQuery(sql,dest_db);
   delete q;
 
   //
   // Copy Entries
   //
-  sql="select TYPE,OWNER,PANEL_NO,ROW_NO,COLUMN_NO,LABEL,CART,DEFAULT_COLOR\
-       from PANELS";
-  q=new RDSqlQuery(sql,src_db);
+  sql=QString("select ")+
+    "TYPE,"+           // 00
+    "OWNER,"+          // 01
+    "PANEL_NO,"+       // 02
+    "ROW_NO,"+         // 03
+    "COLUMN_NO,"+      // 04
+    "LABEL,"+          // 05
+    "CART,"+           // 06
+    "DEFAULT_COLOR "+  // 07
+    "from PANELS";
+  q=new QSqlQuery(sql,src_db);
   while(q->next()) {
-    sql=QString().sprintf("insert into PANELS set \
-                           TYPE=%d,\
-                           OWNER=\"%s\",\
-                           PANEL_NO=%d,\
-                           ROW_NO=%d,\
-                           COLUMN_NO=%d,\
-                           LABEL=\"%s\",\
-                           CART=%d,\
-                           DEFAULT_COLOR=\"%s\"",
-			  q->value(0).toInt(),
-			  (const char *)q->value(1).toString(),
-			  q->value(2).toInt(),
-			  q->value(3).toInt(),
-			  q->value(4).toInt(),
-			  (const char *)q->value(5).toString(),
-			  q->value(6).toInt(),
-			  (const char *)q->value(7).toString());
-    q1=new RDSqlQuery(sql,dest_db);
+    sql=QString("insert into PANELS set ")+
+      QString().sprintf("TYPE=%d,",q->value(0).toInt())+
+      "OWNER=\""+RDEscapeString(q->value(1).toString())+"\","+
+      QString().sprintf("PANEL_NO=%d,",q->value(2).toInt())+
+      QString().sprintf("ROW_NO=%d,",q->value(3).toInt())+
+      QString().sprintf("COLUMN_NO=%d,",q->value(4).toInt())+
+      "LABEL=\""+RDEscapeString(q->value(5).toString())+"\","+
+      QString().sprintf("CART=%d,",q->value(6).toInt())+
+      "DEFAULT_COLOR=\""+RDEscapeString(q->value(7).toString())+"\"";
+    q1=new QSqlQuery(sql,dest_db);
     delete q1;
   }
   delete q;
