@@ -2,7 +2,7 @@
 //
 // The cart slot widget.
 //
-//   (C) Copyright 2012-2014,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2012-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,6 +18,8 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <syslog.h>
+
 #include <qpainter.h>
 #include <qbitmap.h>
 
@@ -33,7 +35,7 @@ RDCartSlot::RDCartSlot(int slotnum,RDRipc *ripc,RDCae *cae,RDStation *station,
 		       RDCueEditDialog *cue_dialog,
 		       const QString &caption,RDAirPlayConf *conf,
 		       QWidget *parent)
-  : QWidget(parent)
+  : RDWidget(parent)
 {
   slot_number=slotnum;
   slot_ripc=ripc;
@@ -46,7 +48,6 @@ RDCartSlot::RDCartSlot(int slotnum,RDRipc *ripc,RDCae *cae,RDStation *station,
   slot_cue_dialog=cue_dialog;
   slot_caption=caption;
   slot_airplay_conf=conf;
-
   slot_svc_names=NULL;
   slot_stop_requested=false;
   slot_logline=new RDLogLine();
@@ -58,14 +59,6 @@ RDCartSlot::RDCartSlot(int slotnum,RDRipc *ripc,RDCae *cae,RDStation *station,
   slot_timescaling_active=false;
   slot_temp_cart=false;
 
-  //
-  // Fonts
-  //
-  QFont big_font("helvetica",36,QFont::Bold);
-  big_font.setPixelSize(36);
-  QFont mid_font("helvetica",14,QFont::Bold);
-  mid_font.setPixelSize(14);
-
   //
   // Palettes
   //
@@ -97,7 +90,7 @@ RDCartSlot::RDCartSlot(int slotnum,RDRipc *ripc,RDCae *cae,RDStation *station,
   //
   slot_start_button=new QPushButton(QString().sprintf("%d",slotnum+1),this);
   slot_start_button->setGeometry(0,0,sizeHint().height(),sizeHint().height());
-  slot_start_button->setFont(big_font);
+  slot_start_button->setFont(hugeButtonFont());
   slot_start_button->setDisabled(true);
   connect(slot_start_button,SIGNAL(clicked()),this,SLOT(startData()));
 
@@ -122,7 +115,7 @@ RDCartSlot::RDCartSlot(int slotnum,RDRipc *ripc,RDCae *cae,RDStation *station,
   slot_load_button->
     setGeometry(sizeHint().height()+5+slot_box->sizeHint().width()+5,0,
 		sizeHint().height(),sizeHint().height());
-  slot_load_button->setFont(mid_font);
+  slot_load_button->setFont(buttonFont());
   connect(slot_load_button,SIGNAL(clicked()),this,SLOT(loadData()));
 
   //
@@ -132,7 +125,7 @@ RDCartSlot::RDCartSlot(int slotnum,RDRipc *ripc,RDCae *cae,RDStation *station,
   slot_options_button->
     setGeometry(2*sizeHint().height()+10+slot_box->sizeHint().width()+5,0,
 		sizeHint().height(),sizeHint().height());
-  slot_options_button->setFont(mid_font);
+  slot_options_button->setFont(buttonFont());
   connect(slot_options_button,SIGNAL(clicked()),this,SLOT(optionsData()));
 
   updateOptions();
@@ -285,7 +278,6 @@ bool RDCartSlot::play()
 	slot_deck->play(slot_logline->playPosition());
       }
       slot_logline->setStartTime(RDLogLine::Actual,QTime::currentTime());
-      //      LogPlayout(RDAirPlayConf::TrafficStart);
       ret=true;
     }
   }
@@ -305,7 +297,9 @@ bool RDCartSlot::stop()
   if(slot_logline->cartNumber()!=0) {
     slot_stop_requested=true;
     slot_deck->stop();
-    //    LogPlayout(RDAirPlayConf::TrafficStop);
+    RDCart *cart=new RDCart(slot_logline->cartNumber());
+    setCart(cart);
+    delete cart;
     ret=true;
   }
   return ret;
@@ -474,6 +468,7 @@ void RDCartSlot::stateChangedData(int id,RDPlayDeck::State state)
 {
   //printf("stateChangedData(%d,%d)\n",id,state);
   short lvls[2]={-10000,-10000};
+  RDCart *cart=NULL;
 
   switch(state) {
   case RDPlayDeck::Playing:
@@ -501,6 +496,9 @@ void RDCartSlot::stateChangedData(int id,RDPlayDeck::State state)
       if(!slot_stop_requested) {
 	switch(slot_options->stopAction()) {
 	case RDSlotOptions::RecueOnStop:
+	  cart=new RDCart(slot_logline->cartNumber());
+	  setCart(cart);
+	  delete cart;
 	  break;
 	  
 	case RDSlotOptions::UnloadOnStop:
@@ -674,20 +672,18 @@ void RDCartSlot::LogPlayout(RDPlayDeck::State state)
           slot_logline->startTime(RDLogLine::Actual));
     QString svctablename=slot_svcname;
     svctablename.replace(" ","_");
-    sql=QString("insert into `")+svctablename+"_SRT` set "+
-      QString().sprintf("LENGTH=%d,LOG_ID=%d,CART_NUMBER=%u,EVENT_TYPE=%d,\
-                       EVENT_SOURCE=%d,EXT_LENGTH=%d,PLAY_SOURCE=%d,	\
-                       CUT_NUMBER=%d,USAGE_CODE=%d,START_SOURCE=%d,",
-			length,
-			slot_number+1,
-			slot_logline->cartNumber(),
-			action,
-			slot_logline->source(),
-			slot_logline->extLength(),
-			RDLogLine::CartSlot,
-			slot_logline->cutNumber(),
-			slot_logline->usageCode(),
-			slot_logline->startSource())+
+    sql=QString("insert into ELR_LINES set ")+
+      "SERVICE_NAME=\""+RDEscapeString(slot_svcname)+"\","+
+      QString().sprintf("LENGTH=%d,",length)+
+      QString().sprintf("LOG_ID=%d,",slot_number+1)+
+      QString().sprintf("CART_NUMBER=%u,",slot_logline->cartNumber())+
+      QString().sprintf("EVENT_TYPE=%d,",action)+
+      QString().sprintf("EVENT_SOURCE=%d,",slot_logline->source())+
+      QString().sprintf("EXT_LENGTH=%d,",slot_logline->extLength())+
+      QString().sprintf("PLAY_SOURCE=%d,",RDLogLine::CartSlot)+
+      QString().sprintf("CUT_NUMBER=%d,",slot_logline->cutNumber())+
+      QString().sprintf("USAGE_CODE=%d,",slot_logline->usageCode())+
+      QString().sprintf("START_SOURCE=%d,",slot_logline->startSource())+
       "STATION_NAME=\""+RDEscapeString(slot_station->name())+"\","+
       "EVENT_DATETIME="+RDCheckDateTime(eventDateTime,"yyyy-MM-dd hh:mm:ss")+
       ","+
