@@ -2,9 +2,7 @@
 //
 //   A class for trapping arbitrary character sequences.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: rdcodetrap.h,v 1.1 2007/09/14 14:06:24 fredg Exp $
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -19,20 +17,14 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-//
 
 #ifndef RDCODETRAP_H
 #define RDCODETRAP_H
 
-
-#include <vector>
-
+#include <qlist.h>
 #include <qobject.h>
 
-using namespace std;
-
-
-struct RTrapEvent {
+struct RDTrapEvent {
   int id;
   char *code;
   int length;
@@ -44,7 +36,7 @@ class RDCodeTrap : public QObject
 {
  Q_OBJECT
  public:
-  RDCodeTrap(QObject *parent=0,const char *name=0);
+  RDCodeTrap(QObject *parent=0);
   ~RDCodeTrap();
   void addTrap(int id,const char *code,int length);
   void removeTrap(int id);
@@ -57,7 +49,7 @@ class RDCodeTrap : public QObject
   void trapped(int id);
 
  private:
-  vector<struct RTrapEvent> trap_events;
+  QList<struct RDTrapEvent> trap_events;
 };
 
 
