@@ -23,6 +23,8 @@
 
 #include <qlabel.h>
 #include <qwidget.h>
+//Added by qt3to4:
+#include <QMouseEvent>
 
 #include <rdcartdrag.h>
 
