@@ -50,10 +50,5 @@ extern "C" {
 #define RD_PYPAD_PYTHON_PATH "/usr/bin/python"
 #define RD_PYPAD_SCRIPT_DIR "${exec_prefix}/lib/rivendell/pypad"
 
-/*
- * runuser(1)
- */
-#define RD_RUNUSER "/usr/sbin/runuser"
-
 
 #endif  // RDPATHS_H
