@@ -2,9 +2,7 @@
 //
 // A class to read an ini formatted configuration file.
 //
-// (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: rdprofile.cpp,v 1.4.8.1 2014/01/20 19:13:30 cvs Exp $
+// (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -19,13 +17,99 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-//
 
 #include <qfile.h>
 #include <qstringlist.h>
-#include <qtextstream.h>
+#include <q3textstream.h>
+
+#include "rdprofile.h"
+
+RDProfileLine::RDProfileLine()
+{
+  clear();
+}
+
+
+QString RDProfileLine::tag() const
+{
+  return line_tag;
+}
+
+
+void RDProfileLine::setTag(QString tag)
+{
+  line_tag=tag;
+}
+
+
+QString RDProfileLine::value() const
+{
+  return line_value;
+}
+
+
+void RDProfileLine::setValue(QString value)
+{
+  line_value=value;
+}
+
+
+void RDProfileLine::clear()
+{
+  line_tag="";
+  line_value="";
+}
+
+
+
+
+
+RDProfileSection::RDProfileSection()
+{
+  clear();
+}
+
+
+QString RDProfileSection::name() const
+{
+  return section_name;
+}
+
+
+void RDProfileSection::setName(QString name)
+{
+  section_name=name;
+}
+
+
+bool RDProfileSection::getValue(QString tag,QString *value) const
+{
+  for(unsigned i=0;i<section_line.size();i++) {
+    if(section_line[i].tag()==tag) {
+      *value=section_line[i].value();
+      return true;
+    }
+  }
+  return false;
+}
+
+
+void RDProfileSection::addValue(QString tag,QString value)
+{
+  section_line.push_back(RDProfileLine());
+  section_line.back().setTag(tag);
+  section_line.back().setValue(value);
+}
+
+
+void RDProfileSection::clear()
+{
+  section_name="";
+  section_line.resize(0);
+}
+
+
 
-#include <rdprofile.h>
 
 
 RDProfile::RDProfile()
@@ -49,11 +133,11 @@ bool RDProfile::setSource(const QString &filename)
   profile_section.push_back(RDProfileSection());
   profile_section.back().setName("");
   QFile *file=new QFile(filename);
-  if(!file->open(IO_ReadOnly)) {
+  if(!file->open(QIODevice::ReadOnly)) {
     delete file;
     return false;
   }
-  QTextStream *text=new QTextStream(file);
+  Q3TextStream *text=new Q3TextStream(file);
   QString line=text->readLine().stripWhiteSpace();
   while(!line.isNull()) {
     if((line.left(1)!=";")&&(line.left(1)!="#")) {
@@ -86,8 +170,8 @@ void RDProfile::setSourceString(const QString &str)
   profile_section.resize(0);
   profile_section.push_back(RDProfileSection());
   profile_section.back().setName("");
-  lines=lines.split("\n",str);
-  for(unsigned i=0;i<lines.size();i++) {
+  lines=str.split("\n");
+  for(int i=0;i<lines.size();i++) {
     QString line=lines[i];
     if((line.left(1)!=";")&&(line.left(1)!="#")) {
       if((line.left(1)=="[")&&(line.right(1)=="]")) {
