@@ -1,8 +1,8 @@
 //   rdpushbutton.cpp
 //
-//   An flashing button widget.
+//   A flashing button widget.
 //
-//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -21,34 +21,66 @@
 #include <qpushbutton.h>
 #include <qpainter.h>
 #include <qpixmap.h>
-#include <qpointarray.h>
+#include <q3pointarray.h>
 #include <qtimer.h>
 #include <qpalette.h>
+//Added by qt3to4:
+#include <QMouseEvent>
 
 #include <rdpushbutton.h>
 
 
-RDPushButton::RDPushButton(QWidget *parent=0)
-  :  QPushButton(parent)
+RDPushButton::RDPushButton(QWidget *parent=0,RDConfig *c)
+  : QPushButton(parent), RDFontEngine(font(),c)
 {
   Init();
 }
 
 
-RDPushButton::RDPushButton(const QString &text,QWidget *parent)
-  : QPushButton(text,parent)
+RDPushButton::RDPushButton(const QString &text,QWidget *parent,RDConfig *c)
+  : QPushButton(text,parent), RDFontEngine(font(),c)
 {
+  plain_text=text;
   Init();
 }
 
-RDPushButton::RDPushButton(const QIconSet &icon,const QString &text,
-			   QWidget *parent)
-  : QPushButton(text,parent)
+RDPushButton::RDPushButton(const QIcon &icon,const QString &text,
+			   QWidget *parent,RDConfig *c)
+  : QPushButton(text,parent), RDFontEngine(font(),c)
 {
+  plain_text=text;
   Init();
 }
 
 
+QString RDPushButton::text() const
+{
+  return plain_text;
+}
+
+
+void RDPushButton::setText(const QString &str)
+{
+  plain_text=str;
+  ComposeText();
+}
+
+
+bool RDPushButton::wordWrap() const
+{
+  return word_wrap_enabled;
+}
+
+
+void RDPushButton::setWordWrap(bool state)
+{
+  if(word_wrap_enabled!=state) {
+    word_wrap_enabled=state;
+    ComposeText();
+  }
+}
+
+
 QColor RDPushButton::flashColor() const
 {
   return flash_color;
@@ -123,20 +155,20 @@ void RDPushButton::setPalette(const QPalette &pal)
 void RDPushButton::mousePressEvent(QMouseEvent *e)
 {
   switch(e->button()) {
-      case QMouseEvent::LeftButton:
-	QPushButton::mousePressEvent(e);
-	break;
+  case Qt::LeftButton:
+    QPushButton::mousePressEvent(e);
+    break;
 	
-      case QMouseEvent::MidButton:
-	emit centerPressed();
-	break;
+  case Qt::MidButton:
+    emit centerPressed();
+    break;
 	
-      case QMouseEvent::RightButton:
-	emit rightPressed();
-	break;
+  case Qt::RightButton:
+    emit rightPressed();
+    break;
 
-      default:
-	break;
+  default:
+    break;
   }
 }
 
@@ -144,32 +176,32 @@ void RDPushButton::mousePressEvent(QMouseEvent *e)
 void RDPushButton::mouseReleaseEvent(QMouseEvent *e)
 {
   switch(e->button()) {
-      case QMouseEvent::LeftButton:
-	QPushButton::mouseReleaseEvent(e);
-	break;
+  case Qt::LeftButton:
+    QPushButton::mouseReleaseEvent(e);
+    break;
 	
-      case QMouseEvent::MidButton:
-	e->accept();
-	emit centerReleased();
-	if((e->x()>=0)&&(e->x()<geometry().width())&&
-	   (e->y()>=0)&&(e->y()<geometry().height())) {
-	  emit centerClicked();
-	  emit centerClicked(button_id,QPoint(e->x(),e->y()));
-	}
-	break;
+  case Qt::MidButton:
+    e->accept();
+    emit centerReleased();
+    if((e->x()>=0)&&(e->x()<geometry().width())&&
+       (e->y()>=0)&&(e->y()<geometry().height())) {
+      emit centerClicked();
+      emit centerClicked(button_id,QPoint(e->x(),e->y()));
+    }
+    break;
 	
-      case QMouseEvent::RightButton:
-	e->accept();
-	emit rightReleased();
-	if((e->x()>=0)&&(e->x()<geometry().width())&&
-	   (e->y()>=0)&&(e->y()<geometry().height())) {
-	  emit rightClicked();
-	  emit rightClicked(button_id,QPoint(e->x(),e->y()));
-	}
-	break;
+  case Qt::RightButton:
+    e->accept();
+    emit rightReleased();
+    if((e->x()>=0)&&(e->x()<geometry().width())&&
+       (e->y()>=0)&&(e->y()<geometry().height())) {
+      emit rightClicked();
+      emit rightClicked(button_id,QPoint(e->x(),e->y()));
+    }
+    break;
 
-      default:
-	break;
+  default:
+    break;
   }
 }
 
@@ -265,6 +297,52 @@ void RDPushButton::flashOff()
 }
 
 
+void RDPushButton::ComposeText()
+{
+  int lines;
+  QStringList f0=plain_text.split(" ",QString::SkipEmptyParts);
+  QFont font(buttonFont().family(),(double)size().height()/2.0,QFont::Bold);
+  QString accum;
+  QString text;
+  int height;
+  bool singleton;
+  int w=90*size().width()/100;
+  int h=90*size().height()/100;
+
+  if(word_wrap_enabled) {
+    do {
+      singleton=false;
+      accum="";
+      text="";
+      font=QFont(font.family(),font.pointSize()-2,QFont::Bold);
+      QFontMetrics fm(font);
+      lines=1;
+      for(int i=0;i<f0.size();i++) {
+	if((fm.width(accum+f0.at(i)+" "))>w) {
+	  if(fm.width(f0.at(i))>w) {
+	    singleton=true;
+	    break;
+	  }
+	  lines++;
+	  accum=f0.at(i)+" ";
+	  text+="\n";
+	}
+	else {
+	  accum+=f0.at(i)+" ";
+	}
+	text+=f0.at(i)+" ";
+      }
+      height=lines*fm.lineSpacing();
+    } while(singleton||(((height>h))&&(font.pointSize()>6)));
+    QPushButton::setText(text.trimmed());
+    QPushButton::setFont(font);
+  }
+  else {
+    QPushButton::setText(plain_text);
+  }
+}
+
+
 void RDPushButton::Init()
 {
   flash_timer=new QTimer();
@@ -275,6 +353,7 @@ void RDPushButton::Init()
   flash_clock_source=RDPushButton::InternalClock;
   flash_period=RDPUSHBUTTON_DEFAULT_FLASH_PERIOD;
   setFlashColor(RDPUSHBUTTON_DEFAULT_FLASH_COLOR);
+  word_wrap_enabled=false;
   button_id=-1;
 }
 
