@@ -2,7 +2,7 @@
 //
 // Abstract a Rivendell Service.
 //
-//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -207,6 +207,19 @@ void RDSvc::setChainto(bool state) const
 }
 
 
+RDSvc::SubEventInheritance RDSvc::subEventInheritance() const
+{
+  return (RDSvc::SubEventInheritance)
+    RDGetSqlValue("SERVICES","NAME",svc_name,"SUB_EVENT_INHERITANCE").toInt();
+}
+
+
+void RDSvc::setSubEventInheritance(RDSvc::SubEventInheritance inherit) const
+{
+  SetRow("SUB_EVENT_INHERITANCE",inherit);
+}
+
+
 QString RDSvc::importTemplate(ImportSource src) const
 {
   QString fieldname=SourceString(src)+"IMPORT_TEMPLATE";
@@ -400,7 +413,7 @@ QString RDSvc::importFilename(ImportSource src,const QDate &date) const
 
 
 bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
-		   const QString &track_str) const
+		   const QString &track_str,bool resolve_implied_times) const
 {
   FILE *infile;
   QString src_str;
@@ -443,7 +456,8 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
     src_str+os_flag+"_PATH,"+           // 00
     src_str+"_LABEL_CART,"+             // 01
     src_str+"_TRACK_CART,"+             // 02
-    src_str+os_flag+"_PREIMPORT_CMD "+  // 03
+    src_str+os_flag+"_PREIMPORT_CMD,"+  // 03
+    "SUB_EVENT_INHERITANCE "+            // 04
     "from SERVICES where "+
     "NAME=\""+RDEscapeString(svc_name)+"\"";
   RDSqlQuery *q=new RDSqlQuery(sql);
@@ -455,6 +469,8 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
   QString label_cart=q->value(1).toString().stripWhiteSpace();
   QString track_cart=q->value(2).toString().stripWhiteSpace();
   QString preimport_cmd=q->value(3).toString();
+  RDSvc::SubEventInheritance inherit=
+    (RDSvc::SubEventInheritance)q->value(4).toUInt();
   delete q;
 
   //
@@ -551,27 +567,20 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
   // Parse and Save
   //
   int line_id=0;
-  bool insert_found=false;
   bool cart_ok=false;
   bool start_time_ok=false;
-  bool line_used=false;
-  bool insert_break=false;
-  bool insert_track=false;
-  bool break_first=false;
-  bool track_first=false;
   QString track_label;
   QTime link_time;
-  int link_length=-1;
 
+  int file_line=0;
   while(fgets(buf,RD_MAX_IMPORT_LINE_LENGTH,infile)!=NULL) {
-    line_used=false;
-    str_buf=QString(buf);
+    str_buf=QString::fromUtf8(buf);
 
     //
     // Cart Number
     //
     cartnum=0;
-    cartname=str_buf.mid(cart_offset,cart_length).stripWhiteSpace();
+    cartname=str_buf.mid(cart_offset,cart_length).trimmed();
 
     //
     // Start Time
@@ -593,11 +602,26 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
     //
     // Length
     //
-    hours_len_buf=str_buf.mid(hours_len_offset,hours_len_length);
-    minutes_len_buf=str_buf.mid(minutes_len_offset,minutes_len_length);
-    seconds_len_buf=str_buf.mid(seconds_len_offset,seconds_len_length);
-    cartlen=3600000*hours_len_buf.toInt()+60000*minutes_len_buf.toInt()+
-      1000*seconds_len_buf.toInt();
+    cartlen=-1;
+    int len=0;
+    bool ok1=true;
+    bool ok2=true;
+    bool ok3=true;
+    if(hours_len_length>0) {
+      QString buf=str_buf.mid(hours_len_offset,hours_len_length);
+      len+=3600000*buf.toUInt(&ok1);
+    }
+    if(minutes_len_length>0) {
+      QString buf=str_buf.mid(minutes_len_offset,minutes_len_length);
+      len+=60000*buf.toInt(&ok2);
+    }
+    if(seconds_len_length>0) {
+      QString buf=str_buf.mid(seconds_len_offset,seconds_len_length);
+      len+=1000*buf.toUInt(&ok3);
+    }
+    if(ok1&&ok2&&ok3) {
+      cartlen=len;
+    }
 
     //
     // External Data
@@ -609,126 +633,175 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
     //
     // Title
     //
-    title=str_buf.mid(title_offset,title_length).stripWhiteSpace();
+    title=str_buf.mid(title_offset,title_length).trimmed();
 
     //
     // Process Line
     //
     cartnum=cartname.toUInt(&cart_ok);
-    if(start_time_ok&&(cart_ok||
-		       ((!label_cart.isEmpty())&&(cartname==label_cart))||
-		       ((!track_cart.isEmpty())&&(cartname==track_cart)))) {
-      sql=QString("insert into IMPORTER_LINES set ")+
-	"STATION_NAME=\""+RDEscapeString(svc_station->name())+"\","+
-	QString().sprintf("PROCESS_ID=%d,",getpid())+
-	QString().sprintf("LINE_ID=%d,",line_id++)+
-	QString().sprintf("START_HOUR=%d,",start_hour)+
+
+    //
+    // Common SQL Elements
+    //
+    sql=QString("insert into IMPORTER_LINES set ")+
+      "STATION_NAME=\""+RDEscapeString(svc_station->name())+"\","+
+      QString().sprintf("PROCESS_ID=%d,",getpid())+
+      QString().sprintf("FILE_LINE=%u,",file_line)+
+      QString().sprintf("LINE_ID=%d,",line_id);
+    if(start_time_ok) {
+      sql+=QString().sprintf("START_HOUR=%d,",start_hour)+
 	QString().sprintf("START_SECS=%d,",
-			  60*start_minutes+start_seconds)+
+			  60*start_minutes+start_seconds);
+    }
+    if(cartlen>=0) {
+      sql+=QString().sprintf("LENGTH=%d,",cartlen);
+    }
+
+    //
+    // Cart
+    //
+    if(start_time_ok&&cart_ok&&(cartnum>0)&&(cartnum<=RD_MAX_CART_NUMBER)) {
+      sql+=QString().sprintf("TYPE=%u,",RDLogLine::Cart)+
+	"EXT_DATA=\""+data_buf.trimmed()+"\","+
+	"EXT_EVENT_ID=\""+eventid_buf.trimmed()+"\","+
+	"EXT_ANNC_TYPE=\""+annctype_buf.trimmed()+"\","+
+	"EXT_CART_NAME=\""+cartname.trimmed()+"\","+
 	QString().sprintf("CART_NUMBER=%u,",cartnum)+
-	"TITLE=\""+RDEscapeString(title)+"\","+
-	QString().sprintf("LENGTH=%d,",cartlen)+
-	"EXT_DATA=\""+data_buf+"\","+
-	"EXT_EVENT_ID=\""+eventid_buf+"\","+
-	"EXT_ANNC_TYPE=\""+annctype_buf+"\","+
-	"EXT_CART_NAME=\""+cartname+"\"";
-      q=new RDSqlQuery(sql);
-      delete q;
-      //
-      // Insert Break
-      //
-      if(insert_break) {
-	sql=QString("update IMPORTER_LINES set ")+
-	  "INSERT_BREAK=\"Y\"";
-	if(break_first) {
-	  sql+=QString().sprintf(",INSERT_FIRST=%d",
-				 RDEventLine::InsertBreak);
-	}
-	if(link_time.isValid()&&(link_length>=0)) {
-	  sql+=",LINK_START_TIME=\""+
-	    link_time.toString("hh:mm:ss")+"\""+
-	    QString().sprintf(",LINK_LENGTH=%d",
-			      link_length);
-	}
-	sql+=QString(" where ")+
-	  "STATION_NAME=\""+RDEscapeString(svc_station->name())+"\" && "+
-	  QString().sprintf("PROCESS_ID=%u && ",getpid())+
-	  QString().sprintf("LINE_ID=%d",line_id-1);
-	q=new RDSqlQuery(sql);
-	delete q;
-      }
-      //
-      // Insert Track
-      //
-      if(insert_track) {
-	if(track_first) {
-	  sql=QString("update IMPORTER_LINES set ")+
-	    "INSERT_TRACK=\"Y\","+
-	    "TRACK_STRING=\""+RDEscapeString(track_label)+"\","+
-	    QString().sprintf("INSERT_FIRST=%d ",RDEventLine::InsertTrack)+
-	    QString("where ")+
-	    "STATION_NAME=\""+RDEscapeString(svc_station->name())+"\" && "+
-	    QString().sprintf("PROCESS_ID=%u && ",getpid())+
-	    QString().sprintf("LINE_ID=%d",line_id-1);
-	}
-	else {
-	  sql=QString("update IMPORTER_LINES set ")+
-	    "INSERT_TRACK=\"Y\","+
-	    "TRACK_STRING=\""+RDEscapeString(track_label)+"\" "+
-	    QString("where ")+
-	    "STATION_NAME=\""+RDEscapeString(svc_station->name())+"\" && "+
-	    QString().sprintf("PROCESS_ID=%u && ",getpid())+
-	    QString().sprintf("LINE_ID=%d",line_id-1);
-	}
-	q=new RDSqlQuery(sql);
-	delete q;
-      }
-      insert_break=false;
-      break_first=false;
-      insert_track=false;
-      track_first=false;
-      insert_found=false;
-      line_used=true;
+	"TITLE=\""+RDEscapeString(title)+"\"";
+      RDSqlQuery::apply(sql);
+      line_id++;
+      file_line++;
+      continue;
     }
-    if((cartname==break_str)&&start_time_ok) {
-      link_time=
-	QTime(start_hour,start_minutes,start_seconds);
-      link_length=cartlen;
-    }
-    else {
-      link_time=QTime();
-      link_length=-1;
-    }
-    if(!line_used) {
-      //
-      // Look for Break and Track Strings
-      //
-      if(!break_str.isEmpty()) {
-	if(str_buf.contains(break_str)) {
-	  insert_break=true;
-	  if(!insert_found) {
-	    break_first=true;
-	    insert_found=true;
-	  }
-	}
-      }
-      if(!track_str.isEmpty()) {
-	if(str_buf.contains(track_str)) {
-	  insert_track=true;
-	  track_label=str_buf;
-	  if(!insert_found) {
-	    track_first=true;
-	    insert_found=true;
-	  }
-	}
+
+    //
+    // Inline Break
+    //
+    if((src==RDSvc::Music)&&(!break_str.isEmpty())) {
+      if(str_buf.contains(break_str)) {
+	sql+=QString().sprintf("TYPE=%u ",RDLogLine::TrafficLink);
+	RDSqlQuery::apply(sql);
+	line_id++;
+	file_line++;
+	continue;
       }
     }
+
+    //
+    // Track Marker
+    //
+    if((!track_str.isEmpty())&&(str_buf.contains(track_str))) {
+      sql+=QString().sprintf("TYPE=%u,",RDLogLine::Track);
+      switch(inherit) {
+      case RDSvc::ParentEvent:
+	sql+="TITLE=\""+RDEscapeString(str_buf.simplified().trimmed())+"\"";
+	break;
+
+      case RDSvc::SchedFile:
+	sql+="TITLE=\""+RDEscapeString(title)+"\"";
+	break;
+      }
+      RDSqlQuery::apply(sql);
+      line_id++;
+      file_line++;
+      continue;
+    }
+
+    //
+    // Label/Note Cart
+    //
+    if((!label_cart.isEmpty())&&(str_buf.contains(label_cart))) {
+      sql+=QString().sprintf("TYPE=%u,",RDLogLine::Marker);
+      switch(inherit) {
+      case RDSvc::ParentEvent:
+	sql+="TITLE=\""+RDEscapeString(str_buf.simplified().trimmed())+"\"";
+	break;
+
+      case RDSvc::SchedFile:
+	sql+="TITLE=\""+RDEscapeString(title)+"\"";
+	break;
+      }
+      RDSqlQuery::apply(sql);
+      line_id++;
+      file_line++;
+      continue;
+    }
+
+    file_line++;
   }
 
   //
   // Cleanup
   //
   fclose(infile);
+
+  //
+  // Resolve Implied Start Time/Duration for Inline Events
+  //
+  if(resolve_implied_times&&subEventInheritance()==RDSvc::ParentEvent) {
+    int prev_hour=0;
+    int prev_secs=0;
+    int prev_length=0;
+    QList<unsigned> prev_ids;
+
+    sql=QString("select ")+
+      "ID,"+          // 00
+      "START_HOUR,"+  // 01
+      "START_SECS,"+  // 02
+      "LENGTH "+      // 03
+      "from IMPORTER_LINES where "+
+      "STATION_NAME=\""+RDEscapeString(svc_station->name())+"\" && "+
+      QString().sprintf("PROCESS_ID=%d ",getpid())+
+      "order by FILE_LINE";
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      if((!q->value(1).isNull())&&(!q->value(2).isNull())&&
+	 (!q->value(3).isNull())) {
+	if(prev_ids.size()>0) {
+	  int len=1000*(q->value(2).toInt()-prev_secs)-prev_length;
+	  if(len<0) {
+	    len=0;
+	  }
+	  sql=QString("update IMPORTER_LINES set ")+
+	    QString().sprintf("START_HOUR=%d,",prev_hour)+
+	    QString().sprintf("START_SECS=%d,",prev_secs+prev_length/1000)+
+	    QString().sprintf("LENGTH=%d ",len)+
+	    "where ";
+	  for(int i=0;i<prev_ids.size();i++) {
+	    sql+=QString().sprintf("(ID=%u)||",prev_ids.at(i));
+	  }
+	  sql=sql.left(sql.length()-2);
+	  RDSqlQuery::apply(sql);
+	  prev_ids.clear();
+	}
+	prev_hour=q->value(1).toInt();
+	prev_secs=q->value(2).toInt();
+	prev_length=q->value(3).toInt();
+      }
+      else {
+	prev_ids.push_back(q->value(0).toUInt());
+      }
+    }
+    delete q;
+
+    //
+    // Handle trailing implied start time events
+    //
+    if(prev_ids.size()>0) {
+      sql=QString("update IMPORTER_LINES set ")+
+	QString().sprintf("START_HOUR=%d,",prev_hour)+
+	QString().sprintf("START_SECS=%d,",prev_secs+prev_length/1000)+
+	"LENGTH=0 "+
+	"where ";
+      for(int i=0;i<prev_ids.size();i++) {
+	sql+=QString().sprintf("(ID=%u)||",prev_ids.at(i));
+      }
+      sql=sql.left(sql.length()-2);
+      RDSqlQuery::apply(sql);
+      prev_ids.clear();
+    }
+  }
+
   return true;
 }
 
@@ -848,6 +921,12 @@ bool RDSvc::linkLog(RDSvc::ImportSource src,const QDate &date,
   QString sql;
   RDSqlQuery *q;
   QString autofill_errors;
+  QTime prev_start_time;
+  RDLogEvent *src_event=NULL;
+  RDLogEvent *dest_event=NULL;
+  RDLogLine *logline=NULL;
+
+  *err_msg="";
 
   RDLogLock *log_lock=new RDLogLock(logname,user,svc_station,this);
   if(!TryLock(log_lock,err_msg)) {
@@ -889,19 +968,30 @@ bool RDSvc::linkLog(RDSvc::ImportSource src,const QDate &date,
   //
   // Import File
   //
-  if(!import(src,date,breakString(),trackString(src))) {
+  if(!import(src,date,breakString(),trackString(src),true)) {
     *err_msg=tr("Import failed");
     delete log_lock;
     return false;
   }
 
+  //
+  // Resolve embedded link parameters
+  //
+  if(src==RDSvc::Music) {
+    if(!ResolveInlineEvents(logname,err_msg)) {
+      delete log_lock;
+      *err_msg=tr("Import file")+": \""+importFilename(src,date)+"\"\n\n"+
+	*err_msg;
+      return false;
+    }
+  }
+
   //
   // Iterate Through the Log
   //
-  RDLogEvent *src_event=new RDLogEvent(logname);
-  RDLogEvent *dest_event=new RDLogEvent(logname);
+  src_event=new RDLogEvent(logname);
+  dest_event=new RDLogEvent(logname);
   src_event->load();
-  RDLogLine *logline=NULL;
   for(int i=0;i<src_event->size();i++) {
     logline=src_event->logLine(i);
     if(logline->type()==src_type) {
@@ -945,26 +1035,57 @@ bool RDSvc::linkLog(RDSvc::ImportSource src,const QDate &date,
   sql=QString("select ")+
     "IMPORTER_LINES.START_HOUR,"+   // 00
     "IMPORTER_LINES.START_SECS,"+   // 01
-    "IMPORTER_LINES.CART_NUMBER,"+  // 02
-    "CART.TITLE "+                  // 03
+    "IMPORTER_LINES.TYPE,"+         // 02
+    "IMPORTER_LINES.CART_NUMBER,"+  // 03
+    "IMPORTER_LINES.TITLE,"+        // 04
+    "CART.TITLE "+                  // 05
     "from IMPORTER_LINES left join CART "+
     "on IMPORTER_LINES.CART_NUMBER=CART.NUMBER where "+
     "IMPORTER_LINES.STATION_NAME=\""+
     RDEscapeString(svc_station->name())+"\" && "+
     QString().sprintf("IMPORTER_LINES.PROCESS_ID=%u && ",getpid())+
-    "IMPORTER_LINES.EVENT_USED=\"N\"";
+    "IMPORTER_LINES.EVENT_USED=\"N\" "+
+    "order by LINE_ID";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     event=true;
-    if(q->value(3).toString().isEmpty()) {
-      cartname=tr("[unknown cart]");
-    }
-    else {
-      cartname=q->value(3).toString();
-    }
+
     link_report+=QString("  ")+
-      RDSvc::timeString(q->value(0).toInt(),q->value(1).toInt())+
-      QString().sprintf(" - %06u - ",q->value(2).toUInt())+cartname+"\n";
+      RDSvc::timeString(q->value(0).toInt(),q->value(1).toInt());
+    switch((RDLogLine::Type)q->value(2).toUInt()) {
+    case RDLogLine::Cart:
+    case RDLogLine::Macro:
+      if(q->value(5).toString().isEmpty()) {
+	cartname=q->value(4).toString();
+      }
+      else {
+	cartname=q->value(5).toString();
+      }
+      link_report+=
+	QString().sprintf(" - %06u - ",q->value(3).toUInt())+cartname+"\n";
+      break;
+
+    case RDLogLine::Marker:
+      link_report+=" - "+tr("Note Cart")+": \""+q->value(4).toString()+"\"\n";
+      break;
+
+    case RDLogLine::Track:
+      link_report+=" - "+tr("Track")+": \""+q->value(4).toString()+"\"\n";
+      break;
+
+    case RDLogLine::TrafficLink:
+      link_report+=" - "+tr("Traffic Link")+"\n";
+      break;
+
+    case RDLogLine::OpenBracket:
+    case RDLogLine::CloseBracket:
+    case RDLogLine::MusicLink:
+    case RDLogLine::Chain:
+    case RDLogLine::UnknownType:
+      link_report+=" - "+tr("Unexpected event")+" \""+
+	RDLogLine::typeText((RDLogLine::Type)q->value(2).toUInt())+"\"\n";
+      break;
+    }
   }
   delete q;
   link_report+="\n";
@@ -1096,6 +1217,11 @@ bool RDSvc::create(const QString &name,QString *err_msg,
   RDSqlQuery *q;
   RDSqlQuery *q1;
 
+  if(name.simplified()!=name) {
+    *err_msg=QObject::tr("whitespace is not permitted in service names");
+    return false;
+  }
+
   sql=QString("select NAME from SERVICES where ")+
     "NAME=\""+RDEscapeString(name)+"\"";
   q=new RDSqlQuery(sql);
@@ -1152,124 +1278,151 @@ bool RDSvc::create(const QString &name,QString *err_msg,
   }
   else {    // Base on Existing Service
     sql=QString("select ")+
-      "NAME_TEMPLATE,"+          // 00
-      "DESCRIPTION_TEMPLATE,"+   // 01
-      "CHAIN_LOG,"+              // 02
-      "TRACK_GROUP,"+            // 03
-      "AUTOSPOT_GROUP,"+         // 04
-      "DEFAULT_LOG_SHELFLIFE,"+  // 05
-      "LOG_SHELFLIFE_ORIGIN,"+   // 06
-      "AUTO_REFRESH,"+           // 07
-      "ELR_SHELFLIFE,"+          // 08
-      "TFC_IMPORT_TEMPLATE,"+    // 09
-      "TFC_PATH,"+               // 10
-      "TFC_CART_OFFSET,"+        // 11
-      "TFC_CART_LENGTH,"+        // 12
-      "TFC_TITLE_OFFSET,"        // 13
-      "TFC_TITLE_LENGTH,"+       // 14
-      "TFC_LEN_HOURS_OFFSET,"    // 15
-      "TFC_LEN_HOURS_LENGTH,"    // 16
-      "TFC_LEN_MINUTES_OFFSET,"  // 17
-      "TFC_LEN_MINUTES_LENGTH,"  // 18
-      "TFC_LEN_SECONDS_OFFSET,"  // 19
-      "TFC_LEN_SECONDS_LENGTH,"  // 20
-      "TFC_HOURS_OFFSET,"+       // 21
-      "TFC_HOURS_LENGTH,"+       // 22
-      "TFC_MINUTES_OFFSET,"+     // 23
-      "TFC_MINUTES_LENGTH,"+     // 24
-      "TFC_SECONDS_OFFSET,"+     // 25
-      "TFC_SECONDS_LENGTH,"+     // 26
-      "TFC_DATA_OFFSET,"+        // 27
-      "TFC_DATA_LENGTH,"+        // 28
-      "TFC_EVENT_ID_OFFSET,"+    // 29
-      "TFC_EVENT_ID_LENGTH,"+    // 30
-      "TFC_ANNC_TYPE_OFFSET,"+   // 31
-      "TFC_ANNC_TYPE_LENGTH,"+   // 32
-      "MUS_IMPORT_TEMPLATE,"+    // 33
-      "MUS_PATH,"+               // 34
-      "MUS_CART_OFFSET,"+        // 35
-      "MUS_CART_LENGTH,"+        // 36
-      "MUS_TITLE_OFFSET,"        // 37
-      "MUS_TITLE_LENGTH,"+       // 38
-      "MUS_LEN_HOURS_OFFSET,"    // 39
-      "MUS_LEN_HOURS_LENGTH,"    // 40
-      "MUS_LEN_MINUTES_OFFSET,"  // 41
-      "MUS_LEN_MINUTES_LENGTH,"  // 42
-      "MUS_LEN_SECONDS_OFFSET,"  // 43
-      "MUS_LEN_SECONDS_LENGTH,"  // 44
-      "MUS_HOURS_OFFSET,"+       // 45
-      "MUS_HOURS_LENGTH,"+       // 46
-      "MUS_MINUTES_OFFSET,"+     // 47
-      "MUS_MINUTES_LENGTH,"+     // 48
-      "MUS_SECONDS_OFFSET,"+     // 49
-      "MUS_SECONDS_LENGTH,"+     // 50
-      "MUS_DATA_OFFSET,"+        // 51
-      "MUS_DATA_LENGTH,"+        // 52
-      "MUS_EVENT_ID_OFFSET,"+    // 53
-      "MUS_EVENT_ID_LENGTH,"+    // 54
-      "MUS_ANNC_TYPE_OFFSET,"+   // 55
-      "MUS_ANNC_TYPE_LENGTH "+   // 56
+      "DESCRIPTION,"+            // 00
+      "NAME_TEMPLATE,"+          // 01
+      "DESCRIPTION_TEMPLATE,"+   // 02
+      "PROGRAM_CODE,"+           // 03
+      "CHAIN_LOG,"+              // 04
+      "SUB_EVENT_INHERITANCE,"+  // 05
+      "TRACK_GROUP,"+            // 06
+      "AUTOSPOT_GROUP,"+         // 07
+      "DEFAULT_LOG_SHELFLIFE,"+  // 08
+      "LOG_SHELFLIFE_ORIGIN,"+   // 09
+      "AUTO_REFRESH,"+           // 10
+      "ELR_SHELFLIFE,"+          // 11
+      "TFC_PREIMPORT_CMD,"+      // 12
+      "TFC_IMPORT_TEMPLATE,"+    // 13
+      "TFC_PATH,"+               // 14
+      "TFC_LABEL_CART,"+         // 15
+      "TFC_TRACK_CART,"+         // 16
+      "TFC_BREAK_STRING,"+       // 17
+      "TFC_TRACK_STRING,"+       // 18
+      "TFC_CART_OFFSET,"+        // 19
+      "TFC_CART_LENGTH,"+        // 20
+      "TFC_TITLE_OFFSET,"        // 21
+      "TFC_TITLE_LENGTH,"+       // 22
+      "TFC_LEN_HOURS_OFFSET,"    // 23
+      "TFC_LEN_HOURS_LENGTH,"    // 24
+      "TFC_LEN_MINUTES_OFFSET,"  // 25
+      "TFC_LEN_MINUTES_LENGTH,"  // 26
+      "TFC_LEN_SECONDS_OFFSET,"  // 27
+      "TFC_LEN_SECONDS_LENGTH,"  // 28
+      "TFC_HOURS_OFFSET,"+       // 29
+      "TFC_HOURS_LENGTH,"+       // 30
+      "TFC_MINUTES_OFFSET,"+     // 31
+      "TFC_MINUTES_LENGTH,"+     // 32
+      "TFC_SECONDS_OFFSET,"+     // 33
+      "TFC_SECONDS_LENGTH,"+     // 34
+      "TFC_DATA_OFFSET,"+        // 35
+      "TFC_DATA_LENGTH,"+        // 36
+      "TFC_EVENT_ID_OFFSET,"+    // 37
+      "TFC_EVENT_ID_LENGTH,"+    // 38
+      "TFC_ANNC_TYPE_OFFSET,"+   // 39
+      "TFC_ANNC_TYPE_LENGTH,"+   // 40
+      "MUS_PREIMPORT_CMD,"+      // 41
+      "MUS_IMPORT_TEMPLATE,"+    // 42
+      "MUS_PATH,"+               // 43
+      "MUS_LABEL_CART,"+         // 44
+      "MUS_TRACK_CART,"+         // 45
+      "MUS_BREAK_STRING,"+       // 46
+      "MUS_TRACK_STRING,"+       // 47
+      "MUS_CART_OFFSET,"+        // 48
+      "MUS_CART_LENGTH,"+        // 49
+      "MUS_TITLE_OFFSET,"        // 50
+      "MUS_TITLE_LENGTH,"+       // 51
+      "MUS_LEN_HOURS_OFFSET,"    // 52
+      "MUS_LEN_HOURS_LENGTH,"    // 53
+      "MUS_LEN_MINUTES_OFFSET,"  // 54
+      "MUS_LEN_MINUTES_LENGTH,"  // 55
+      "MUS_LEN_SECONDS_OFFSET,"  // 56
+      "MUS_LEN_SECONDS_LENGTH,"  // 57
+      "MUS_HOURS_OFFSET,"+       // 58
+      "MUS_HOURS_LENGTH,"+       // 59
+      "MUS_MINUTES_OFFSET,"+     // 60
+      "MUS_MINUTES_LENGTH,"+     // 61
+      "MUS_SECONDS_OFFSET,"+     // 62
+      "MUS_SECONDS_LENGTH,"+     // 63
+      "MUS_DATA_OFFSET,"+        // 64
+      "MUS_DATA_LENGTH,"+        // 65
+      "MUS_EVENT_ID_OFFSET,"+    // 66
+      "MUS_EVENT_ID_LENGTH,"+    // 67
+      "MUS_ANNC_TYPE_OFFSET,"+   // 68
+      "MUS_ANNC_TYPE_LENGTH "+   // 69
       " from SERVICES where NAME=\""+RDEscapeString(exemplar)+"\"";
     q=new RDSqlQuery(sql);
     if(q->first()) {
       sql=QString("insert into SERVICES set ")+
-	"NAME_TEMPLATE=\""+RDEscapeString(q->value(0).toString())+"\","+
-	"DESCRIPTION_TEMPLATE=\""+RDEscapeString(q->value(1).toString())+"\","+
-	"CHAIN_LOG=\""+RDEscapeString(q->value(2).toString())+"\","+
-	"TRACK_GROUP=\""+RDEscapeString(q->value(3).toString())+"\","+
-	"AUTOSPOT_GROUP=\""+RDEscapeString(q->value(4).toString())+"\","+
-	QString().sprintf("DEFAULT_LOG_SHELFLIFE=%d,",q->value(5).toInt())+
-	QString().sprintf("LOG_SHELFLIFE_ORIGIN=%d,",q->value(6).toInt())+
-	"AUTO_REFRESH=\""+RDEscapeString(q->value(7).toString())+"\","+
-	QString().sprintf("ELR_SHELFLIFE=%d,",q->value(8).toInt())+
-	"TFC_IMPORT_TEMPLATE=\""+RDEscapeString(q->value(9).toString())+"\","+
-	"TFC_PATH=\""+RDEscapeString(q->value(10).toString())+"\","+
-	QString().sprintf("TFC_CART_OFFSET=%d,",q->value(11).toInt())+
-	QString().sprintf("TFC_CART_LENGTH=%d,",q->value(12).toInt())+
-	QString().sprintf("TFC_TITLE_OFFSET=%d,",q->value(13).toInt())+
-	QString().sprintf("TFC_TITLE_LENGTH=%d,",q->value(14).toInt())+
-	QString().sprintf("TFC_LEN_HOURS_OFFSET=%d,",q->value(15).toInt())+
-	QString().sprintf("TFC_LEN_HOURS_LENGTH=%d,",q->value(16).toInt())+
-	QString().sprintf("TFC_LEN_MINUTES_OFFSET=%d,",q->value(17).toInt())+
-	QString().sprintf("TFC_LEN_MINUTES_LENGTH=%d,",q->value(18).toInt())+
-	QString().sprintf("TFC_LEN_SECONDS_OFFSET=%d,",q->value(19).toInt())+
-	QString().sprintf("TFC_LEN_SECONDS_LENGTH=%d,",q->value(20).toInt())+
-	QString().sprintf("TFC_HOURS_OFFSET=%d,",q->value(21).toInt())+
-	QString().sprintf("TFC_HOURS_LENGTH=%d,",q->value(22).toInt())+
-	QString().sprintf("TFC_MINUTES_OFFSET=%d,",q->value(23).toInt())+
-	QString().sprintf("TFC_MINUTES_LENGTH=%d,",q->value(24).toInt())+
-	QString().sprintf("TFC_SECONDS_OFFSET=%d,",q->value(25).toInt())+
-	QString().sprintf("TFC_SECONDS_LENGTH=%d,",q->value(26).toInt())+
-	QString().sprintf("TFC_DATA_OFFSET=%d,",q->value(27).toInt())+
-	QString().sprintf("TFC_DATA_LENGTH=%d,",q->value(28).toInt())+
-	QString().sprintf("TFC_EVENT_ID_OFFSET=%d,",q->value(29).toInt())+
-	QString().sprintf("TFC_EVENT_ID_LENGTH=%d,",q->value(30).toInt())+
-	QString().sprintf("TFC_ANNC_TYPE_OFFSET=%d,",q->value(31).toInt())+
-	QString().sprintf("TFC_ANNC_TYPE_LENGTH=%d,",q->value(32).toInt())+
-	"MUS_IMPORT_TEMPLATE=\""+RDEscapeString(q->value(33).toString())+"\","+
-	"MUS_PATH=\""+RDEscapeString(q->value(34).toString())+"\","+
-	QString().sprintf("MUS_CART_OFFSET=%d,",q->value(35).toInt())+
-	QString().sprintf("MUS_CART_LENGTH=%d,",q->value(36).toInt())+
-	QString().sprintf("MUS_TITLE_OFFSET=%d,",q->value(37).toInt())+
-	QString().sprintf("MUS_TITLE_LENGTH=%d,",q->value(38).toInt())+
-	QString().sprintf("MUS_LEN_HOURS_OFFSET=%d,",q->value(39).toInt())+
-	QString().sprintf("MUS_LEN_HOURS_LENGTH=%d,",q->value(40).toInt())+
-	QString().sprintf("MUS_LEN_MINUTES_OFFSET=%d,",q->value(41).toInt())+
-	QString().sprintf("MUS_LEN_MINUTES_LENGTH=%d,",q->value(42).toInt())+
-	QString().sprintf("MUS_LEN_SECONDS_OFFSET=%d,",q->value(43).toInt())+
-	QString().sprintf("MUS_LEN_SECONDS_LENGTH=%d,",q->value(44).toInt())+
-	QString().sprintf("MUS_HOURS_OFFSET=%d,",q->value(45).toInt())+
-	QString().sprintf("MUS_HOURS_LENGTH=%d,",q->value(46).toInt())+
-	QString().sprintf("MUS_MINUTES_OFFSET=%d,",q->value(47).toInt())+
-	QString().sprintf("MUS_MINUTES_LENGTH=%d,",q->value(48).toInt())+
-	QString().sprintf("MUS_SECONDS_OFFSET=%d,",q->value(49).toInt())+
-	QString().sprintf("MUS_SECONDS_LENGTH=%d,",q->value(50).toInt())+
-	QString().sprintf("MUS_DATA_OFFSET=%d,",q->value(51).toInt())+
-	QString().sprintf("MUS_DATA_LENGTH=%d,",q->value(52).toInt())+
-	QString().sprintf("MUS_EVENT_ID_OFFSET=%d,",q->value(53).toInt())+
-	QString().sprintf("MUS_EVENT_ID_LENGTH=%d,",q->value(54).toInt())+
-	QString().sprintf("MUS_ANNC_TYPE_OFFSET=%d,",q->value(55).toInt())+
-	QString().sprintf("MUS_ANNC_TYPE_LENGTH=%d,",q->value(56).toInt())+
+	"DESCRIPTION=\""+
+	RDEscapeString(tr("Copy of")+" "+q->value(0).toString())+"\","+
+	"NAME_TEMPLATE=\""+RDEscapeString(q->value(1).toString())+"\","+
+	"DESCRIPTION_TEMPLATE=\""+RDEscapeString(q->value(2).toString())+"\","+
+	"PROGRAM_CODE=\""+RDEscapeString(q->value(3).toString())+"\","+
+	"CHAIN_LOG=\""+RDEscapeString(q->value(4).toString())+"\","+
+	QString().sprintf("SUB_EVENT_INHERITANCE=%d,",q->value(5).toInt())+
+	"TRACK_GROUP=\""+RDEscapeString(q->value(6).toString())+"\","+
+	"AUTOSPOT_GROUP=\""+RDEscapeString(q->value(7).toString())+"\","+
+	QString().sprintf("DEFAULT_LOG_SHELFLIFE=%d,",q->value(8).toInt())+
+	QString().sprintf("LOG_SHELFLIFE_ORIGIN=%d,",q->value(9).toInt())+
+	"AUTO_REFRESH=\""+RDEscapeString(q->value(10).toString())+"\","+
+	QString().sprintf("ELR_SHELFLIFE=%d,",q->value(11).toInt())+
+	"TFC_PREIMPORT_CMD=\""+RDEscapeString(q->value(12).toString())+"\","+
+	"TFC_IMPORT_TEMPLATE=\""+RDEscapeString(q->value(13).toString())+"\","+
+	"TFC_PATH=\""+RDEscapeString(q->value(14).toString())+"\","+
+	"TFC_LABEL_CART=\""+RDEscapeString(q->value(15).toString())+"\","+
+	"TFC_TRACK_CART=\""+RDEscapeString(q->value(16).toString())+"\","+
+	"TFC_BREAK_STRING=\""+RDEscapeString(q->value(17).toString())+"\","+
+	"TFC_TRACK_STRING=\""+RDEscapeString(q->value(18).toString())+"\","+
+	QString().sprintf("TFC_CART_OFFSET=%d,",q->value(19).toInt())+
+	QString().sprintf("TFC_CART_LENGTH=%d,",q->value(20).toInt())+
+	QString().sprintf("TFC_TITLE_OFFSET=%d,",q->value(21).toInt())+
+	QString().sprintf("TFC_TITLE_LENGTH=%d,",q->value(22).toInt())+
+	QString().sprintf("TFC_LEN_HOURS_OFFSET=%d,",q->value(23).toInt())+
+	QString().sprintf("TFC_LEN_HOURS_LENGTH=%d,",q->value(24).toInt())+
+	QString().sprintf("TFC_LEN_MINUTES_OFFSET=%d,",q->value(25).toInt())+
+	QString().sprintf("TFC_LEN_MINUTES_LENGTH=%d,",q->value(26).toInt())+
+	QString().sprintf("TFC_LEN_SECONDS_OFFSET=%d,",q->value(27).toInt())+
+	QString().sprintf("TFC_LEN_SECONDS_LENGTH=%d,",q->value(28).toInt())+
+	QString().sprintf("TFC_HOURS_OFFSET=%d,",q->value(29).toInt())+
+	QString().sprintf("TFC_HOURS_LENGTH=%d,",q->value(30).toInt())+
+	QString().sprintf("TFC_MINUTES_OFFSET=%d,",q->value(31).toInt())+
+	QString().sprintf("TFC_MINUTES_LENGTH=%d,",q->value(32).toInt())+
+	QString().sprintf("TFC_SECONDS_OFFSET=%d,",q->value(33).toInt())+
+	QString().sprintf("TFC_SECONDS_LENGTH=%d,",q->value(34).toInt())+
+	QString().sprintf("TFC_DATA_OFFSET=%d,",q->value(35).toInt())+
+	QString().sprintf("TFC_DATA_LENGTH=%d,",q->value(36).toInt())+
+	QString().sprintf("TFC_EVENT_ID_OFFSET=%d,",q->value(37).toInt())+
+	QString().sprintf("TFC_EVENT_ID_LENGTH=%d,",q->value(38).toInt())+
+	QString().sprintf("TFC_ANNC_TYPE_OFFSET=%d,",q->value(39).toInt())+
+	QString().sprintf("TFC_ANNC_TYPE_LENGTH=%d,",q->value(40).toInt())+
+	"MUS_PREIMPORT_CMD=\""+RDEscapeString(q->value(41).toString())+"\","+
+	"MUS_IMPORT_TEMPLATE=\""+RDEscapeString(q->value(42).toString())+"\","+
+	"MUS_PATH=\""+RDEscapeString(q->value(43).toString())+"\","+
+	"MUS_LABEL_CART=\""+RDEscapeString(q->value(44).toString())+"\","+
+	"MUS_TRACK_CART=\""+RDEscapeString(q->value(45).toString())+"\","+
+	"MUS_BREAK_STRING=\""+RDEscapeString(q->value(46).toString())+"\","+
+	"MUS_TRACK_STRING=\""+RDEscapeString(q->value(47).toString())+"\","+
+	QString().sprintf("MUS_CART_OFFSET=%d,",q->value(48).toInt())+
+	QString().sprintf("MUS_CART_LENGTH=%d,",q->value(49).toInt())+
+	QString().sprintf("MUS_TITLE_OFFSET=%d,",q->value(50).toInt())+
+	QString().sprintf("MUS_TITLE_LENGTH=%d,",q->value(51).toInt())+
+	QString().sprintf("MUS_LEN_HOURS_OFFSET=%d,",q->value(52).toInt())+
+	QString().sprintf("MUS_LEN_HOURS_LENGTH=%d,",q->value(53).toInt())+
+	QString().sprintf("MUS_LEN_MINUTES_OFFSET=%d,",q->value(54).toInt())+
+	QString().sprintf("MUS_LEN_MINUTES_LENGTH=%d,",q->value(55).toInt())+
+	QString().sprintf("MUS_LEN_SECONDS_OFFSET=%d,",q->value(56).toInt())+
+	QString().sprintf("MUS_LEN_SECONDS_LENGTH=%d,",q->value(57).toInt())+
+	QString().sprintf("MUS_HOURS_OFFSET=%d,",q->value(58).toInt())+
+	QString().sprintf("MUS_HOURS_LENGTH=%d,",q->value(59).toInt())+
+	QString().sprintf("MUS_MINUTES_OFFSET=%d,",q->value(60).toInt())+
+	QString().sprintf("MUS_MINUTES_LENGTH=%d,",q->value(61).toInt())+
+	QString().sprintf("MUS_SECONDS_OFFSET=%d,",q->value(62).toInt())+
+	QString().sprintf("MUS_SECONDS_LENGTH=%d,",q->value(63).toInt())+
+	QString().sprintf("MUS_DATA_OFFSET=%d,",q->value(64).toInt())+
+	QString().sprintf("MUS_DATA_LENGTH=%d,",q->value(65).toInt())+
+	QString().sprintf("MUS_EVENT_ID_OFFSET=%d,",q->value(66).toInt())+
+	QString().sprintf("MUS_EVENT_ID_LENGTH=%d,",q->value(67).toInt())+
+	QString().sprintf("MUS_ANNC_TYPE_OFFSET=%d,",q->value(68).toInt())+
+	QString().sprintf("MUS_ANNC_TYPE_LENGTH=%d,",q->value(69).toInt())+
 	"NAME=\""+RDEscapeString(name)+"\"";
       delete q;
       q=new RDSqlQuery(sql);
@@ -1625,3 +1778,159 @@ bool RDSvc::CheckId(std::vector<int> *v,int value)
   v->push_back(value);
   return true;
 }
+
+
+QString RDSvc::MakeErrorLine(int indent,unsigned lineno,const QString &msg) 
+  const
+{
+  QString margin;
+
+  for(int i=0;i<indent;i++) {
+    margin+=" ";
+  }
+  return margin+tr("Line")+QString().sprintf(" %u: ",1+lineno)+msg+"\n";
+}
+
+
+bool RDSvc::ResolveInlineEvents(const QString &logname,QString *err_msg)
+  const
+{
+  RDLogEvent *evt=NULL;
+  RDLogLine *logline=NULL;
+  QTime start;
+  QTime end;
+  QString sql;
+  RDSqlQuery *q=NULL;
+  bool ok=false;
+
+  switch(subEventInheritance()) {
+  case RDSvc::ParentEvent:
+    evt=new RDLogEvent(logname);
+    evt->load();
+    ok=true;
+    for(int i=0;i<evt->size();i++) {
+      logline=evt->logLine(i);
+      if(logline->type()==RDLogLine::MusicLink) {
+	start=logline->linkStartTime();
+	end=logline->linkStartTime().addSecs(logline->linkLength());
+	sql=QString("select ")+
+	  "ID,"+          // 00
+	  "FILE_LINE "+   // 01
+	  "from IMPORTER_LINES where "+
+	  "IMPORTER_LINES.STATION_NAME=\""+
+	  RDEscapeString(svc_station->name())+"\" && "+
+	  QString().sprintf("IMPORTER_LINES.PROCESS_ID=%u && ",getpid())+
+	  QString().sprintf("TYPE=%u && ",RDLogLine::TrafficLink)+
+	  QString().sprintf("START_HOUR=%d && ",start.hour())+
+	  QString().sprintf("START_SECS>=%d && ",
+			    60*start.minute()+start.second())+
+	  QString().sprintf("START_SECS<%d",60*start.minute()+start.second()+logline->linkLength()/1000);
+	q=new RDSqlQuery(sql);
+	if(q->size()>1) {
+	  *err_msg+=tr("In event")+" \""+logline->linkEventName()+"\"@"+
+	    logline->startTime(RDLogLine::Logged).toString("hh:mm:ss")+":\n";
+	  while(q->next()) {
+	    *err_msg+=MakeErrorLine(4,q->value(1).toUInt(),
+				    tr("multiple inline traffic breaks not permitted within the same music event"));
+	  }
+	  *err_msg+="\n";
+	  ok=false;
+	}
+	if(q->first()) {
+	  sql=QString("update IMPORTER_LINES set ")+
+	    "LINK_START_TIME=\""+
+	    logline->linkStartTime().toString("hh:mm:ss")+"\","+
+	    QString().sprintf("LINK_LENGTH=%d where ",logline->linkLength())+
+	    QString().sprintf("ID=%u",q->value(0).toUInt());
+	  RDSqlQuery::apply(sql);
+	}
+	delete q;
+      }
+    }
+    delete evt;
+    evt=NULL;
+
+    if(!ok) {
+      return false;
+    }
+    break;
+
+  case RDSvc::SchedFile:
+    //
+    // Verify that all inline traffic and voicetrack events have explicit
+    // start times and length
+    //
+    sql=QString("select ")+
+      "FILE_LINE,"+   // 00
+      "TYPE "+        // 01
+      "from IMPORTER_LINES where "+
+      "IMPORTER_LINES.STATION_NAME=\""+
+      RDEscapeString(svc_station->name())+"\" && "+
+      QString().sprintf("IMPORTER_LINES.PROCESS_ID=%u && ",getpid())+
+      QString().sprintf("((TYPE=%u) || ",RDLogLine::TrafficLink)+
+      QString().sprintf("(TYPE=%u) ||",RDLogLine::Marker)+
+      QString().sprintf("(TYPE=%u)) && ",RDLogLine::Track)+
+      "(START_HOUR is null || START_SECS is null || LENGTH is null)";
+    ok=true;
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      switch((RDLogLine::Type)q->value(1).toUInt()) {
+      case RDLogLine::Marker:
+	*err_msg+=MakeErrorLine(0,q->value(0).toUInt(),
+			       tr("invalid start time and/or length on note cart."));
+	break;
+
+      case RDLogLine::TrafficLink:
+	*err_msg+=MakeErrorLine(0,q->value(0).toUInt(),
+			       tr("invalid start time and/or length on inline traffic break."));
+	break;
+
+      case RDLogLine::Track:
+	*err_msg+=MakeErrorLine(0,q->value(0).toUInt(),
+			       tr("invalid start time and/or length on track marker."));
+	break;
+
+      case RDLogLine::Cart:
+      case RDLogLine::Macro:
+      case RDLogLine::OpenBracket:
+      case RDLogLine::CloseBracket:
+      case RDLogLine::Chain:
+      case RDLogLine::MusicLink:
+      case RDLogLine::UnknownType:
+	*err_msg+=MakeErrorLine(0,q->value(0).toUInt(),
+			       tr("unexpected event type")+
+			       " \""+RDLogLine::typeText((RDLogLine::Type)q->value(1).toUInt())+"\"");
+	break;
+      }
+      ok=false;
+    }
+    delete q;
+    if(!ok) {
+      return false;
+    }
+
+    //
+    // Resolve link parameters
+    //
+    sql=QString("select ")+
+      "ID,"+          // 00
+      "START_HOUR,"+  // 01
+      "START_SECS,"+  // 02
+      "LENGTH "+      // 03
+      "from IMPORTER_LINES where "+
+      QString().sprintf("TYPE=%u",RDLogLine::TrafficLink);
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      sql=QString("update IMPORTER_LINES set ")+
+	"LINK_START_TIME=\""+QTime(q->value(1).toInt(),0,0).
+	addSecs(q->value(2).toInt()).toString("hh:mm:ss")+"\","+
+	QString().sprintf("LINK_LENGTH=%d where ",q->value(3).toInt())+
+	QString().sprintf("ID=%u",q->value(0).toUInt());
+      RDSqlQuery::apply(sql);
+    }
+    delete q;
+    break;
+  }
+
+  return true;
+}
