@@ -2,9 +2,7 @@
 //
 // Add a Rivendell Host Variable
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: add_hostvar.h,v 1.6 2010/07/29 19:32:34 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,9 +21,8 @@
 #ifndef ADD_HOSTVAR_H
 #define ADD_HOSTVAR_H
 
-#include <qdialog.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
+#include <q3listbox.h>
+#include <q3textedit.h>
 #include <qpixmap.h>
 #include <qcheckbox.h>
 #include <qsqldatabase.h>
@@ -33,16 +30,15 @@
 #include <qcombobox.h>
 #include <qspinbox.h>
 
+#include <rddialog.h>
 #include <rdstation.h>
-#include <rdcatch_connect.h>
 
-
-class AddHostvar : public QDialog
+class AddHostvar : public RDDialog
 {
   Q_OBJECT
  public:
   AddHostvar(QString station,QString *var,QString *varvalue,QString *remark,
-	       QWidget *parent=0,const char *name=0);
+	     QWidget *parent=0);
   ~AddHostvar();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
