@@ -2,7 +2,7 @@
 //
 // Add a Rivendell Replicator Configuration
 //
-//   (C) Copyright 2010,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,27 +18,30 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
 #include <qstring.h>
 #include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
+#include <q3listbox.h>
+#include <q3textedit.h>
 #include <qlabel.h>
 #include <qpainter.h>
 #include <qevent.h>
 #include <qmessagebox.h>
 #include <qcheckbox.h>
-#include <qbuttongroup.h>
+#include <q3buttongroup.h>
 #include <rddb.h>
 
-#include <edit_replicator.h>
-#include <add_replicator.h>
+#include <rdescape_string.h>
 #include <rdpasswd.h>
 #include <rdtextvalidator.h>
 
+#include "edit_replicator.h"
+#include "add_replicator.h"
+
 AddReplicator::AddReplicator(QString *rname,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   repl_name=rname;
 
   //
@@ -49,20 +52,12 @@ AddReplicator::AddReplicator(QString *rname,QWidget *parent)
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  setCaption(tr("Add Replicator"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont user_font=QFont("Helvetica",12,QFont::Normal);
-  user_font.setPixelSize(12);
+  setWindowTitle("RDAdmin - "+tr("Add Replicator"));
 
   //
   // Text Validator
   //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
+  RDTextValidator *validator=new RDTextValidator(this);
 
   //
   // Replicator Name
@@ -71,10 +66,10 @@ AddReplicator::AddReplicator(QString *rname,QWidget *parent)
   repl_name_edit->setGeometry(145,11,sizeHint().width()-150,19);
   repl_name_edit->setMaxLength(10);
   repl_name_edit->setValidator(validator);
-  QLabel *label=new QLabel(repl_name_edit,tr("&New Replicator Name:"),this);
+  QLabel *label=new QLabel(repl_name_edit,tr("Replicator Name:"),this);
   label->setGeometry(10,11,130,19);
-  label->setFont(font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   //  Ok Button
@@ -82,7 +77,7 @@ AddReplicator::AddReplicator(QString *rname,QWidget *parent)
   QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   ok_button->setDefault(true);
-  ok_button->setFont(font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -92,7 +87,7 @@ AddReplicator::AddReplicator(QString *rname,QWidget *parent)
   QPushButton *cancel_button=new QPushButton(this);
   cancel_button->
     setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
-  cancel_button->setFont(font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 }
@@ -126,9 +121,8 @@ void AddReplicator::okData()
     return;
   }
 
-  sql=QString().sprintf("insert into REPLICATORS set NAME=\"%s\"",
-			(const char *)repl_name_edit->text());
-
+  sql=QString("insert into REPLICATORS set ")+
+    "NAME=\""+RDEscapeString(repl_name_edit->text())+"\"";
   q=new RDSqlQuery(sql);
   if(!q->isActive()) {
     QMessageBox::warning(this,tr("Replicator Exists"),tr("A replicator with that name already exists!"));
@@ -139,8 +133,8 @@ void AddReplicator::okData()
 
   EditReplicator *replicator=new EditReplicator(repl_name_edit->text(),this);
   if(replicator->exec()<0) {
-    sql=QString().sprintf("delete from REPLICATORS where NAME=\"%s\"",
-			  (const char *)repl_name_edit->text());
+    sql=QString("delete from REPLICATORS where ")+
+      "NAME=\""+RDEscapeString(repl_name_edit->text())+"\"";
     q=new RDSqlQuery(sql);
     delete q;
     delete replicator;
