@@ -3,6 +3,8 @@
 // Edit scheduler codes dialog
 //
 //   Stefan Gabriel <stg@st-gabriel.de>
+//   (C) Copyright 2005-2018
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,26 +20,19 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qpushbutton.h>
-#include <qstring.h>
-#include <qlistbox.h>
-#include <qpainter.h>
-#include <qevent.h>
-#include <qmessagebox.h>
-#include <qbuttongroup.h>
-
-#include <rduser.h>
-#include <rdpasswd.h>
-#include <rdtextvalidator.h>
 #include <rddb.h>
-#include <edit_group.h>
-#include <edit_schedcodes.h>
+#include <rdescape_string.h>
+#include <rdtextvalidator.h>
 
-EditSchedCode::EditSchedCode(QString schedCode,QString description,
+#include "edit_group.h"
+#include "edit_schedcodes.h"
+
+EditSchedCode::EditSchedCode(QString schedcode,QString description,
 			     QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   //
   // Fix the Window Size
   //
@@ -46,16 +41,10 @@ EditSchedCode::EditSchedCode(QString schedCode,QString description,
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  schedCode_code=new QString(schedCode);
-  schedCode_description=new QString(description);
+  schedcode_code=new QString(schedcode);
+  schedcode_description=new QString(description);
   
-  setCaption(tr("Scheduler Code: ")+schedCode);
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
+  setWindowTitle("RDAdmin - "+tr("Scheduler Code: ")+schedcode);
 
   //
   // Text Validators
@@ -65,28 +54,28 @@ EditSchedCode::EditSchedCode(QString schedCode,QString description,
   //
   // Code Name
   //
-  schedCode_name_edit=new QLineEdit(this);
-  schedCode_name_edit->setGeometry(125,11,100,19);
-  schedCode_name_edit->setMaxLength(10);
-  schedCode_name_edit->setReadOnly(true);
-  QLabel *schedCode_name_label=
-    new QLabel(schedCode_name_edit,tr("Scheduler Code:"),this);
-  schedCode_name_label->setGeometry(10,11,110,19);
-  schedCode_name_label->setFont(font);
-  schedCode_name_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  schedcode_name_edit=new QLineEdit(this);
+  schedcode_name_edit->setGeometry(125,11,100,19);
+  schedcode_name_edit->setMaxLength(10);
+  schedcode_name_edit->setReadOnly(true);
+  QLabel *schedcode_name_label=
+    new QLabel(schedcode_name_edit,tr("Scheduler Code:"),this);
+  schedcode_name_label->setGeometry(10,11,110,19);
+  schedcode_name_label->setFont(labelFont());
+  schedcode_name_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Code Description
   //
-  schedCode_description_edit=new QLineEdit(this);
-  schedCode_description_edit->setGeometry(125,32,sizeHint().width()-135,19);
-  schedCode_description_edit->setMaxLength(255);
-  schedCode_description_edit->setValidator(validator);
-  QLabel *schedCode_description_label=
-    new QLabel(schedCode_description_edit,tr("Code Description:"),this);
-  schedCode_description_label->setGeometry(10,32,110,19);
-  schedCode_description_label->setFont(font);
-  schedCode_description_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  schedcode_description_edit=new QLineEdit(this);
+  schedcode_description_edit->setGeometry(125,32,sizeHint().width()-135,19);
+  schedcode_description_edit->setMaxLength(255);
+  schedcode_description_edit->setValidator(validator);
+  QLabel *schedcode_description_label=
+    new QLabel(schedcode_description_edit,tr("Code Description:"),this);
+  schedcode_description_label->setGeometry(10,32,110,19);
+  schedcode_description_label->setFont(labelFont());
+  schedcode_description_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   //  Ok Button
@@ -94,7 +83,7 @@ EditSchedCode::EditSchedCode(QString schedCode,QString description,
   QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   ok_button->setDefault(true);
-  ok_button->setFont(font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -104,22 +93,22 @@ EditSchedCode::EditSchedCode(QString schedCode,QString description,
   QPushButton *cancel_button=new QPushButton(this);
   cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
 			     80,50);
-  cancel_button->setFont(font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
   //
   // Populate Fields
   //
-  schedCode_name_edit->setText(*schedCode_code);
-  schedCode_description_edit->setText(*schedCode_description);
+  schedcode_name_edit->setText(*schedcode_code);
+  schedcode_description_edit->setText(*schedcode_description);
 }
 
 
 EditSchedCode::~EditSchedCode()
 {
-  delete schedCode_name_edit;
-  delete schedCode_description_edit;
+  delete schedcode_name_edit;
+  delete schedcode_description_edit;
 }
 
 
@@ -140,12 +129,13 @@ void EditSchedCode::okData()
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("update SCHED_CODES set DESCRIPTION=\"%s\" where CODE=\"%s\"",(const char *)schedCode_description_edit->text(),(const char *)schedCode_name_edit->text());
-
+  sql=QString("update SCHED_CODES set ")+
+    "DESCRIPTION=\""+RDEscapeString(schedcode_description_edit->text())+"\" "+
+    "where CODE=\""+RDEscapeString(schedcode_name_edit->text())+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 
-  *schedCode_description=schedCode_description_edit->text();
+  *schedcode_description=schedcode_description_edit->text();
   done(0);
 }
 
