@@ -2,9 +2,7 @@
 //
 // Global Definitions for RDAdmin
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: globals.h,v 1.11 2011/06/23 22:30:44 cvs Exp $
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,23 +18,14 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
 #ifndef GLOBALS_H
 #define GLOBALS_H
 
-#include <rdripc.h>
-#include <rdconfig.h>
-#include <rduser.h>
-#include <rdstation.h>
 #include <rdcart_dialog.h>
 
 //
 // Global Classes
 //
-extern RDRipc *rdripc;
-extern RDConfig *admin_config;
-extern RDUser *admin_user;
-extern RDStation *admin_station;
 extern RDCartDialog *admin_cart_dialog;
 extern QString admin_svc_name;
 extern QString admin_admin_username;
@@ -47,4 +36,5 @@ extern bool admin_skip_backup;
 extern QString admin_backup_filename;
 extern void PrintError(const QString &str,bool interactive);
 
+
 #endif  // GLOBALS_H
