@@ -2,7 +2,7 @@
 //
 // Display System Information for Rivendell
 //
-//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,15 +20,7 @@
 #ifndef INFO_DIALOG_H
 #define INFO_DIALOG_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
-#include <qspinbox.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-
-#include <rdtty.h>
+#include <rddialog.h>
 
 //
 // Globals
@@ -36,7 +28,7 @@
 extern const unsigned char xpm_infobanner1[];
 extern const unsigned char xpm_infobanner2[];
 
-class InfoDialog : public QDialog
+class InfoDialog : public RDDialog
 {
  Q_OBJECT
  public:
@@ -45,6 +37,7 @@ class InfoDialog : public QDialog
   QSizePolicy sizePolicy() const;
 
  private slots:
+  void viewCreditsData();
   void viewLicenseData();
   void closeData();
 };
