@@ -2,7 +2,7 @@
 //
 // Test a Rivendell Log Import
 //
-//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -35,6 +35,11 @@
 #include "globals.h"
 #include "test_import.h"
 
+#include "../icons/play.xpm"
+#include "../icons/marker.xpm"
+#include "../icons/mic16.xpm"
+#include "../icons/traffic.xpm"
+
 TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,QWidget *parent)
   : RDDialog(parent)
 {
@@ -61,6 +66,14 @@ TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,QWidget *parent)
     break;
   }
 
+  //
+  // Create Icons
+  //
+  test_playout_map=new QPixmap(play_xpm);
+  test_marker_map=new QPixmap(marker_xpm);
+  test_mic16_map=new QPixmap(mic16_xpm);
+  test_traffic_map=new QPixmap(traffic_xpm);
+
   //
   // Date Selector
   //
@@ -104,20 +117,27 @@ TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,QWidget *parent)
   //
   test_events_list=new RDListView(this);
   test_events_list->setItemMargin(2);
-  test_events_list->addColumn(tr("Start Time"));
+  test_events_list->setSortColumn(0);
+  test_events_list->setSortOrder(Qt::Ascending);
+  test_events_list->setAllColumnsShowFocus(true);
+  test_events_list->addColumn("");
   test_events_list->setColumnAlignment(0,Qt::AlignCenter);
-  test_events_list->addColumn(tr("Cart"));
+  test_events_list->addColumn(tr("Start Time"));
   test_events_list->setColumnAlignment(1,Qt::AlignCenter);
+  test_events_list->addColumn(tr("Cart"));
+  test_events_list->setColumnAlignment(2,Qt::AlignCenter);
   test_events_list->addColumn(tr("Len"));
-  test_events_list->setColumnAlignment(2,Qt::AlignRight);
+  test_events_list->setColumnAlignment(3,Qt::AlignRight);
   test_events_list->addColumn(tr("Title"));
-  test_events_list->setColumnAlignment(3,Qt::AlignLeft);
+  test_events_list->setColumnAlignment(4,Qt::AlignLeft);
   test_events_list->addColumn(tr("GUID"));
-  test_events_list->setColumnAlignment(4,Qt::AlignCenter);
-  test_events_list->addColumn(tr("Event ID"));
   test_events_list->setColumnAlignment(5,Qt::AlignCenter);
-  test_events_list->addColumn(tr("Announcement Type"));
+  test_events_list->addColumn(tr("Event ID"));
   test_events_list->setColumnAlignment(6,Qt::AlignCenter);
+  test_events_list->addColumn(tr("Annc Type"));
+  test_events_list->setColumnAlignment(7,Qt::AlignCenter);
+  test_events_list->addColumn(tr("Line"));
+  test_events_list->setColumnAlignment(8,Qt::AlignRight);
   test_events_list->setColumnSortType(0,RDListView::LineSort);
   test_events_label=new QLabel(test_events_list,tr("Imported Events"),this);
   test_events_label->setGeometry(15,160,sizeHint().width()-30,18);
@@ -174,7 +194,7 @@ void TestImport::importData()
 
   test_events_list->clear();
   if(!test_svc->import(test_src,test_date_edit->date(),test_svc->breakString(),
-		       test_svc->trackString(test_src))) {
+		       test_svc->trackString(test_src),true)) {
     QMessageBox::information(this,tr("Import Error"),
 			     tr("There was an error during import\nplease check your settings and try again."));
     return;
@@ -187,62 +207,59 @@ void TestImport::importData()
     "EXT_DATA,"+       // 04
     "EXT_EVENT_ID,"+   // 05
     "EXT_ANNC_TYPE,"+  // 06
-    "INSERT_BREAK,"+   // 07
-    "INSERT_TRACK,"+   // 08
-    "INSERT_FIRST,"+   // 09
-    "TITLE,"+          // 10
-    "TRACK_STRING "+   // 11
+    "TITLE,"+          // 07
+    "TYPE,"+           // 08
+    "FILE_LINE "+      // 09
     "from IMPORTER_LINES where "+
     "STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\" && "+
-    QString().sprintf("PROCESS_ID=%u",getpid());
+    QString().sprintf("PROCESS_ID=%u ",getpid())+
+    "order by LINE_ID";
   RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
-    if(q->value(9).toUInt()==RDEventLine::InsertBreak) {
-      if(q->value(7).toString()=="Y") {
-	item=new RDListViewItem(test_events_list);
-	item->setLine(next_line++);
-	item->
-	  setText(0,RDSvc::timeString(q->value(0).toInt(),
-				      q->value(1).toInt()));
-	item->setText(1,tr("[spot break]"));
-      }
-      if(q->value(8).toString()=="Y") {
-	item=new RDListViewItem(test_events_list);
-	item->setLine(next_line++);
-	item->setText(0,RDSvc::timeString(q->value(0).toInt(),
-					  q->value(1).toInt()));
-	item->setText(1,"["+q->value(11).toString()+"]");
-      }
-    }
-    else {
-      if(q->value(8).toString()=="Y") {
-	item=new RDListViewItem(test_events_list);
-	item->setLine(next_line++);
-	item->setText(0,RDSvc::timeString(q->value(0).toInt(),
-					  q->value(1).toInt()));
-	item->setText(1,"["+q->value(11).toString()+"]");
-      }
-      if(q->value(7).toString()=="Y") {
-	item=new RDListViewItem(test_events_list);
-	item->setLine(next_line++);
-	item->
-	  setText(0,RDSvc::timeString(q->value(0).toInt(),
-				      q->value(1).toInt()));
-	item->setText(1,tr("[spot break]"));
-      }
-    }
     item=new RDListViewItem(test_events_list);
     item->setLine(next_line++);
-    item->setText(0,RDSvc::timeString(q->value(0).toInt(),
-				      q->value(1).toInt()));
-    item->setText(1,q->value(2).toString());
-    if(q->value(3).toInt()>=0) {
-      item->setText(2,RDGetTimeLength(q->value(3).toInt(),false,false));
+    if((!q->value(0).isNull())&&(!q->value(1).isNull())) {
+      item->setText(1,RDSvc::timeString(q->value(0).toInt(),
+					q->value(1).toInt()));
+    }
+    if(!q->value(3).isNull()) {
+      item->setText(3,RDGetTimeLength(q->value(3).toInt(),false,false));
+    }
+    item->setText(5,q->value(4).toString().trimmed());
+    item->setText(6,q->value(5).toString().trimmed());
+    item->setText(7,q->value(6).toString().trimmed());
+    item->setText(8,QString().sprintf("%u",1+q->value(9).toUInt()));
+    switch((RDLogLine::Type)q->value(8).toUInt()) {
+    case RDLogLine::Cart:
+      item->setPixmap(0,*test_playout_map);
+      item->setText(2,q->value(2).toString());
+      item->setText(4,q->value(7).toString().trimmed());
+      break;
+
+    case RDLogLine::Marker:
+      item->setPixmap(0,*test_marker_map);
+      item->setText(2,tr("NOTE"));
+      item->setText(4,q->value(7).toString().trimmed());
+      break;
+
+    case RDLogLine::TrafficLink:
+      item->setPixmap(0,*test_traffic_map);
+      item->setText(4,tr("[spot break]"));
+      break;
+
+    case RDLogLine::Track:
+      item->setPixmap(0,*test_mic16_map);
+      item->setText(4,tr("[voice track]"));
+      break;
+
+    case RDLogLine::Macro:
+    case RDLogLine::OpenBracket:
+    case RDLogLine::CloseBracket:
+    case RDLogLine::Chain:
+    case RDLogLine::MusicLink:
+    case RDLogLine::UnknownType:
+      break;
     }
-    item->setText(3,q->value(10).toString());
-    item->setText(4,q->value(4).toString());
-    item->setText(5,q->value(5).toString());
-    item->setText(6,q->value(6).toString());
   }
   delete q;
 
