@@ -449,7 +449,7 @@ void EditUpload::urlChangedData(const QString &str)
 {
   QUrl url(str);
   QString protocol=url.protocol().lower();
-  if((protocol=="ftp")||(protocol=="file")||
+  if((protocol=="ftp")||(protocol=="ftps")||(protocol=="file")||
      (protocol=="scp")||(protocol=="sftp")) {
     edit_username_label->setEnabled(true);
     edit_username_edit->setEnabled(true);
@@ -483,9 +483,8 @@ void EditUpload::selectCartData()
 
 void EditUpload::setFormatData()
 {
-  RDExportSettingsDialog *dialog=
-    new RDExportSettingsDialog(&edit_settings,this);
-  dialog->exec();
+  RDExportSettingsDialog *dialog=new RDExportSettingsDialog("RDCatch",this);
+  dialog->exec(&edit_settings);
   delete dialog;
   edit_format_edit->setText(edit_settings.description());
 }
@@ -527,7 +526,7 @@ void EditUpload::okData()
   }
   QUrl url(edit_url_edit->text());
   QString protocol=url.protocol();
-  if((protocol!="ftp")&&(protocol!="file")&&
+  if((protocol!="ftp")&&(protocol!="ftps")&&(protocol!="file")&&
      (protocol!="scp")&&(protocol!="sftp")) {
     QMessageBox::warning(this,
 			 tr("Invalid URL"),tr("Unsupported URL protocol!"));
