@@ -2,7 +2,7 @@
 //
 // Local macros for the Rivendell netcatcher daemon
 //
-//   (C) Copyright 2002-2009,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2009,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,10 +18,13 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <syslog.h>
+
+#include <rdapplication.h>
 #include <rdcart.h>
 #include <rduser.h>
 
-#include <rdcatchd.h>
+#include "rdcatchd.h"
 
 void MainObject::RunLocalMacros(RDMacro *rml)
 {
@@ -39,7 +42,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
   QDateTime dt;
   RDUser *user;
   bool ok=false;
-  CatchEvent e(catch_rdstation,RDConfiguration());
+  CatchEvent e(rda->station(),RDConfiguration());
   unsigned event_ptr=0;
   QString sql;
   RDSqlQuery *q;
@@ -67,7 +70,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  }
 	  if(rml->echoRequested()) {
 	    rml->acknowledge(true);
-	    catch_ripc->sendRml(rml);
+	    rda->ripc()->sendRml(rml);
 	  }
 	  return;
 	}
@@ -75,7 +78,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
     }
     if(rml->echoRequested()) {
       rml->acknowledge(false);
-      catch_ripc->sendRml(rml);
+      rda->ripc()->sendRml(rml);
     }
     break;
 
@@ -88,22 +91,22 @@ void MainObject::RunLocalMacros(RDMacro *rml)
        (dst_cartnum<1)||(dst_cartnum>RD_MAX_CART_NUMBER)||
        (cutnum<1)||(cutnum>RD_MAX_CUT_NUMBER)||
        (dst_cutnum<1)||(dst_cutnum>RD_MAX_CUT_NUMBER)||
-       (catch_ripc->user().isEmpty())) {
+       (rda->ripc()->user().isEmpty())) {
       if(rml->echoRequested()) {
 	rml->acknowledge(false);
-	catch_ripc->sendRml(rml);
+	rda->ripc()->sendRml(rml);
       }
       return;
     }
-    user=new RDUser(catch_ripc->user());
+    user=new RDUser(rda->ripc()->user());
     cut=new RDCut(cartnum,cutnum);
-    ok=cut->copyTo(catch_rdstation,user,RDCut::cutName(dst_cartnum,dst_cutnum),
-		   catch_config);
+    ok=cut->copyTo(rda->station(),user,RDCut::cutName(dst_cartnum,dst_cutnum),
+		   rda->config());
     delete cut;
     delete user;
     if(rml->echoRequested()) {
       rml->acknowledge(ok);
-      catch_ripc->sendRml(rml);
+      rda->ripc()->sendRml(rml);
     }
     break;
 
@@ -113,7 +116,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       if(ExecuteMacroCart(cart)) {
 	if(rml->echoRequested()) {
 	  rml->acknowledge(true);
-	  catch_ripc->sendRml(rml);
+	  rda->ripc()->sendRml(rml);
 	}
 	delete cart;
 	return;
@@ -122,7 +125,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
     else {
       if(rml->echoRequested()) {
 	rml->acknowledge(false);
-	catch_ripc->sendRml(rml);
+	rda->ripc()->sendRml(rml);
       }
     }
     delete cart;
@@ -136,7 +139,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
     if(rml->argQuantity()!=4) {
       if(rml->echoRequested()) {
 	rml->acknowledge(false);
-	catch_ripc->sendRml(rml);
+	rda->ripc()->sendRml(rml);
       }
       return;
     }
@@ -148,18 +151,18 @@ void MainObject::RunLocalMacros(RDMacro *rml)
        ||len==0) {
       if(rml->echoRequested()) {
 	rml->acknowledge(false);
-	catch_ripc->sendRml(rml);
+	rda->ripc()->sendRml(rml);
       }
       return;
     }
     cut=new RDCut(cartnum,cutnum);
-    deck=new RDDeck(catch_config->stationName(),chan);
+    deck=new RDDeck(rda->config()->stationName(),chan);
     if((!cut->exists())||(!deck->isActive())) {
       delete cut;
       delete deck;
       if(rml->echoRequested()) {
 	rml->acknowledge(false);
-	catch_ripc->sendRml(rml);
+	rda->ripc()->sendRml(rml);
       }
       return;
     }
@@ -174,17 +177,16 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	catch_record_pending_maxlen[chan-1]=len;
 	if(rml->echoRequested()) {
 	  rml->acknowledge(true);
-	  catch_ripc->sendRml(rml);
+	  rda->ripc()->sendRml(rml);
 	}
 	return;
       }
       else {
-	LogLine(RDConfig::LogWarning,QString().
-		sprintf("unable to handle RS macro for deck %d: device busy",
-			chan));
+	syslog(LOG_WARNING,"unable to handle RS macro for deck %d: device busy",
+	       chan);
 	if(rml->echoRequested()) {
 	  rml->acknowledge(false);
-	  catch_ripc->sendRml(rml);
+	  rda->ripc()->sendRml(rml);
 	}
 	return;
       }
@@ -196,7 +198,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
     StartRmlRecording(chan,cartnum,cutnum,len);
     if(rml->echoRequested()) {
       rml->acknowledge(true);
-      catch_ripc->sendRml(rml);
+      rda->ripc()->sendRml(rml);
     }
     break;
 
@@ -204,7 +206,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
     if(rml->argQuantity()!=1) {
       if(rml->echoRequested()) {
 	rml->acknowledge(false);
-	catch_ripc->sendRml(rml);
+	rda->ripc()->sendRml(rml);
       }
       return;
     }
@@ -213,8 +215,8 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       switch(catch_record_deck_status[chan-1]) {
       case RDDeck::Recording:
 	catch_record_aborting[chan-1]=true;
-	catch_cae->stopRecord(catch_record_card[chan-1],
-			      catch_record_stream[chan-1]);
+	rda->cae()->stopRecord(catch_record_card[chan-1],
+			       catch_record_stream[chan-1]);
 	break;
 	
       case RDDeck::Waiting:
@@ -227,7 +229,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
     }
     if(rml->echoRequested()) {
       rml->acknowledge(true);
-      catch_ripc->sendRml(rml);
+      rda->ripc()->sendRml(rml);
     }
     break;
 
