@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell Cart
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_cart.cpp,v 1.74.2.7.2.2 2014/05/28 21:21:41 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,42 +18,21 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <vector>
-
-#include <qbitmap.h>
-#include <unistd.h>
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistview.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qpainter.h>
-#include <qevent.h>
 #include <qmessagebox.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
-#include <qtooltip.h>
-#include <qvalidator.h>
 
-#include <rddb.h>
-#include <rd.h>
 #include <rdconf.h>
-#include <rdaudio_exists.h>
-#include <rdsystem.h>
 #include <rdescape_string.h>
-#include <rdaudioexport.h>
-#include <rdupload.h>
 
-#include <cdripper.h>
-#include <edit_cart.h>
-#include <record_cut.h>
-#include <edit_schedulercodes.h>
-#include <edit_notes.h>
+#include "cdripper.h"
+#include "edit_cart.h"
+#include "edit_notes.h"
+#include "edit_schedulercodes.h"
+#include "rdlibrary.h"
+#include "record_cut.h"
 
 EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
-		   QWidget *parent,const char *name,QListView *lib_cart_list)
-  : QDialog(parent,name,true)
+		   QWidget *parent,const char *name,Q3ListView *lib_cart_list)
+  : RDDialog(parent)
 {
   bool modification_allowed;
   rdcart_cart=NULL;
@@ -84,13 +61,14 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   if(lib_cart_list_edit==NULL) {
     rdcart_cart=new RDCart(number);
     rdcart_import_path=path;
-    setCaption(QString().sprintf("%06u",rdcart_cart->number())+" - "+
-	       rdcart_cart->title());
+    setWindowTitle("RDLibrary - "+tr("Edit Cart")+
+		   QString().sprintf(" %06u",rdcart_cart->number())+" ["+
+		   rdcart_cart->title()+"]");
     modification_allowed=
-      lib_user->modifyCarts()&&rdcart_cart->owner().isEmpty();
+      rda->user()->modifyCarts()&&rdcart_cart->owner().isEmpty();
   }
   else {
-    setCaption("Edit Carts");
+    setWindowTitle("RDLibrary - "+tr("Edit Carts [multiple]"));
     modification_allowed=true;
   }
 
@@ -98,77 +76,66 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   // Create Default Audio Cut
   //
   if(new_cart&&((rdcart_cart->type()==RDCart::Audio))) {
-    if(rdcart_cart->addCut(rdlibrary_conf->defaultFormat(),
-			   rdlibrary_conf->defaultBitrate(),
-			   rdlibrary_conf->defaultChannels())<0) {
+    if(rdcart_cart->addCut(rda->libraryConf()->defaultFormat(),
+			   rda->libraryConf()->defaultBitrate(),
+			   rda->libraryConf()->defaultChannels())<0) {
       QMessageBox::warning(this,tr("RDLibrary - Edit Cart"),
 			   tr("This cart cannot contain any additional cuts!"));
     }
   }
 
-  //
-  // Generate Fonts
-  //
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont line_edit_font=QFont("Helvetica",12,QFont::Normal);
-  line_edit_font.setPixelSize(12);
-
   if(lib_cart_list_edit==NULL) {
-  //
-  // Cart Number
-  //
-  rdcart_number_edit=new QLineEdit(this,"rdcart_number_edit");
-  rdcart_number_edit->setGeometry(135,11,70,21);
-  rdcart_number_edit->setFont(line_edit_font);
-  rdcart_number_edit->setMaxLength(6);
-  rdcart_number_edit->setReadOnly(true);
-  QLabel *rdcart_number_label=new QLabel(rdcart_number_edit,tr("Number:"),this,
-				       "rdcart_number_label");
-  rdcart_number_label->setGeometry(10,13,120,19);
-  rdcart_number_label->setFont(button_font);
-  rdcart_number_label->setAlignment(AlignRight|ShowPrefix);
+    //
+    // Cart Number
+    //
+    rdcart_number_edit=new QLineEdit(this);
+    rdcart_number_edit->setGeometry(135,11,70,21);
+    rdcart_number_edit->setMaxLength(6);
+    rdcart_number_edit->setReadOnly(true);
+    QLabel *rdcart_number_label=
+      new QLabel(rdcart_number_edit,tr("Number:"),this);
+    rdcart_number_label->setGeometry(10,13,120,21);
+    rdcart_number_label->setFont(labelFont());
+    rdcart_number_label->
+      setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
   }
 
   //
   // Cart Group
   //
-  rdcart_group_box=new QComboBox(this,"rdcart_group_box");
+  rdcart_group_box=new QComboBox(this);
   if(lib_cart_list_edit==NULL) {
     rdcart_group_box->setGeometry(280,11,140,21);
   }
   else {
-    rdcart_group_box->setGeometry(135,38,110,19);
+    rdcart_group_box->setGeometry(135,38,110,21);
   }
-  rdcart_group_box->setFont(line_edit_font);
-  rdcart_group_edit=new QLineEdit(this,"rdcart_group_edit");
+  rdcart_group_edit=new QLineEdit(this);
   rdcart_group_edit->setGeometry(280,11,140,21);
-  rdcart_group_edit->setFont(line_edit_font);
   rdcart_group_edit->setReadOnly(true);
-  QLabel *rdcart_group_label=new QLabel(rdcart_group_box,tr("Group:"),this,
-				       "rdcart_group_label");
+  QLabel *rdcart_group_label=new QLabel(rdcart_group_box,tr("Group:"),this);
   if(lib_cart_list_edit==NULL) {
-    rdcart_group_label->setGeometry(215,13,60,19);
+    rdcart_group_label->setGeometry(215,13,60,21);
   }
   else {
-    rdcart_group_label->setGeometry(10,38,120,19);
+    rdcart_group_label->setGeometry(10,38,120,21);
   }
-  rdcart_group_label->setFont(button_font);
-  rdcart_group_label->setAlignment(AlignRight|ShowPrefix);
+  rdcart_group_label->setFont(labelFont());
+  rdcart_group_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Cart Type
   //
-  rdcart_type_edit=new QLineEdit(this,"rdcart_type_edit");
+  rdcart_type_edit=new QLineEdit(this);
   rdcart_type_edit->setGeometry(500,11,80,21);
-  rdcart_type_edit->setFont(line_edit_font);
   rdcart_type_edit->setMaxLength(6);
   rdcart_type_edit->setReadOnly(true);
-  QLabel *rdcart_type_label=new QLabel(rdcart_type_edit,tr("Type:"),this,
-				       "rdcart_type_label");
-  rdcart_type_label->setGeometry(440,13,55,19);
-  rdcart_type_label->setFont(button_font);
-  rdcart_type_label->setAlignment(AlignRight|ShowPrefix);
+  QLabel *rdcart_type_label=new QLabel(rdcart_type_edit,tr("Type:"),this);
+  rdcart_type_label->setGeometry(440,13,55,21);
+  rdcart_type_label->setFont(labelFont());
+  rdcart_type_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
   if(lib_cart_list_edit!=NULL) {
     rdcart_type_label->hide();
     rdcart_type_edit->hide();
@@ -177,18 +144,17 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   //
   // Cart Average Length
   //
-  rdcart_average_length_edit=new QLineEdit(this,"rdcart_average_length_edit");
+  rdcart_average_length_edit=new QLineEdit(this);
   rdcart_average_length_edit->setGeometry(135,36,70,21);
-  rdcart_average_length_edit->setFont(line_edit_font);
   rdcart_average_length_edit->setMaxLength(10);
-  rdcart_average_length_edit->setAlignment(AlignRight);
+  rdcart_average_length_edit->setAlignment(Qt::AlignRight);
   rdcart_average_length_edit->setReadOnly(true);
-  QLabel *rdcart_average_length_label=new QLabel(rdcart_average_length_edit,
-						tr("Average Length:"),this,
-						"rdcart_average_length_label");
-  rdcart_average_length_label->setGeometry(10,38,120,19);
-  rdcart_average_length_label->setFont(button_font);
-  rdcart_average_length_label->setAlignment(AlignRight|ShowPrefix);
+  QLabel *rdcart_average_length_label=
+    new QLabel(rdcart_average_length_edit,tr("Average Length:"),this);
+  rdcart_average_length_label->setGeometry(10,38,120,21);
+  rdcart_average_length_label->setFont(labelFont());
+  rdcart_average_length_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
   if(lib_cart_list_edit!=NULL) {
     rdcart_average_length_label->hide();
     rdcart_average_length_edit->hide();
@@ -197,15 +163,14 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   //
   // Cart Enforce Length
   //
-  rdcart_controls.enforce_length_box=new QCheckBox(this,
-					       "rdcart_enforce_length_button");
-  rdcart_controls.enforce_length_box->setGeometry(285,38,20,15);
-  QLabel *rdcart_enforce_length_label=new QLabel(rdcart_controls.enforce_length_box,
-					        tr("Enforce Length"),this,
-						"rdcart_enforce_length_label");
-  rdcart_enforce_length_label->setGeometry(305,38,110,19);
-  rdcart_enforce_length_label->setFont(button_font);
-  rdcart_enforce_length_label->setAlignment(AlignLeft|ShowPrefix);
+  rdcart_controls.enforce_length_box=new QCheckBox(this);
+  rdcart_controls.enforce_length_box->setGeometry(285,41,20,15);
+  QLabel *rdcart_enforce_length_label=
+    new QLabel(rdcart_controls.enforce_length_box,tr("Enforce Length"),this);
+  rdcart_enforce_length_label->setGeometry(305,38,110,21);
+  rdcart_enforce_length_label->setFont(labelFont());
+  rdcart_enforce_length_label->
+    setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
   connect(rdcart_controls.enforce_length_box,SIGNAL(toggled(bool)),
 	  this,SLOT(forcedLengthData(bool)));
   if(lib_cart_list_edit!=NULL) {
@@ -216,24 +181,21 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   //
   // Cart Forced Length
   //
-  rdcart_controls.forced_length_edit=
-    new RDTimeEdit(this,"rdcart_forced_length_edit");
+  rdcart_controls.forced_length_edit=new RDTimeEdit(this);
   rdcart_controls.forced_length_edit->setGeometry(530,36,85,21);
   rdcart_controls.forced_length_edit->
     setDisplay(RDTimeEdit::Hours|RDTimeEdit::Minutes|RDTimeEdit::Seconds|
 	       RDTimeEdit::Tenths);
-  rdcart_controls.forced_length_edit->setFont(line_edit_font);
-  rdcart_forced_length_ledit=new QLineEdit(this,"rdcart_forced_length_edit");
+  rdcart_forced_length_ledit=new QLineEdit(this);
   rdcart_forced_length_ledit->setGeometry(535,36,80,21);
-  rdcart_forced_length_ledit->setFont(line_edit_font);
   rdcart_forced_length_ledit->hide();
   rdcart_forced_length_ledit->setReadOnly(true);
-  rdcart_forced_length_label=new QLabel(rdcart_controls.forced_length_edit,
-					tr("Forced Length:"),this,
-					"rdcart_forced_length_label");
-  rdcart_forced_length_label->setGeometry(415,38,110,19);
-  rdcart_forced_length_label->setFont(button_font);
-  rdcart_forced_length_label->setAlignment(AlignRight|ShowPrefix);
+  rdcart_forced_length_label=
+    new QLabel(rdcart_controls.forced_length_edit,tr("Forced Length:"),this);
+  rdcart_forced_length_label->setGeometry(415,38,110,20);
+  rdcart_forced_length_label->setFont(labelFont());
+  rdcart_forced_length_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
   if(lib_cart_list_edit!=NULL) {
     rdcart_forced_length_label->hide();
     rdcart_controls.forced_length_edit->hide();
@@ -242,15 +204,14 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   //
   // Cart Preserve Pitch
   //
-  rdcart_preserve_pitch_button=new QCheckBox(this,
-					       "rdcart_preserve_pitch_button");
+  rdcart_preserve_pitch_button=new QCheckBox(this);
   rdcart_preserve_pitch_button->setGeometry(430,38,20,15);
-  rdcart_preserve_pitch_label=new QLabel(rdcart_preserve_pitch_button,
-					 tr("Preserve Pitch"),this,
-					 "rdcart_preserve_pitch_label");
-  rdcart_preserve_pitch_label->setGeometry(450,38,140,19);
-  rdcart_preserve_pitch_label->setFont(button_font);
-  rdcart_preserve_pitch_label->setAlignment(AlignLeft|ShowPrefix);
+  rdcart_preserve_pitch_label=
+    new QLabel(rdcart_preserve_pitch_button,tr("Preserve Pitch"),this);
+  rdcart_preserve_pitch_label->setGeometry(450,38,140,21);
+  rdcart_preserve_pitch_label->setFont(labelFont());
+  rdcart_preserve_pitch_label->
+    setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
   // ???????????????????????????????
   rdcart_preserve_pitch_button->hide();
   rdcart_preserve_pitch_label->hide();
@@ -258,82 +219,79 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   //
   // Cart Title
   //
-  rdcart_controls.title_edit=new QLineEdit(this,"rdcart_title_edit");
+  rdcart_controls.title_edit=new QLineEdit(this);
   rdcart_controls.title_edit->setGeometry(135,60,480,21);
-  rdcart_controls.title_edit->setFont(line_edit_font);
   rdcart_controls.title_edit->setMaxLength(255);
-  QLabel *rdcart_title_label=new QLabel(rdcart_controls.title_edit,tr("&Title:"),this,
-				       "rdcart_title_label");
-  rdcart_title_label->setGeometry(10,62,120,19);
-  rdcart_title_label->setFont(button_font);
-  rdcart_title_label->setAlignment(AlignRight|ShowPrefix);
+  QLabel *rdcart_title_label=
+    new QLabel(rdcart_controls.title_edit,tr("&Title:"),this);
+  rdcart_title_label->setGeometry(10,62,120,21);
+  rdcart_title_label->setFont(labelFont());
+  rdcart_title_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Cart Start Date
   //
-  rdcart_start_date_edit=new QLineEdit(this,"rdcart_start_date_edit");
+  rdcart_start_date_edit=new QLineEdit(this);
   rdcart_start_date_edit->setGeometry(135,84,100,21);
-  rdcart_start_date_edit->setFont(line_edit_font);
   rdcart_start_date_edit->setMaxLength(255);
-  QLabel *rdcart_start_date_label=new QLabel(rdcart_start_date_edit,
-					     tr("&Start Date:"),this,
-					     "rdcart_start_date_label");
-  rdcart_start_date_label->setGeometry(10,86,120,19);
-  rdcart_start_date_label->setFont(button_font);
-  rdcart_start_date_label->setAlignment(AlignRight|ShowPrefix);
+  QLabel *rdcart_start_date_label=
+    new QLabel(rdcart_start_date_edit,tr("&Start Date:"),this);
+  rdcart_start_date_label->setGeometry(10,86,120,21);
+  rdcart_start_date_label->setFont(labelFont());
+  rdcart_start_date_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
   rdcart_start_date_edit->hide();
   rdcart_start_date_label->hide();
 
   //
   // Cart End Date
   //
-  rdcart_end_date_edit=new QLineEdit(this,"rdcart_end_date_edit");
+  rdcart_end_date_edit=new QLineEdit(this);
   rdcart_end_date_edit->setGeometry(350,84,100,21);
-  rdcart_end_date_edit->setFont(line_edit_font);
   rdcart_end_date_edit->setMaxLength(255);
-  QLabel *rdcart_end_date_label=new QLabel(rdcart_end_date_edit,
-					     tr("&End Date:"),this,
-					     "rdcart_end_date_label");
-  rdcart_end_date_label->setGeometry(260,86,85,19);
-  rdcart_end_date_label->setFont(button_font);
-  rdcart_end_date_label->setAlignment(AlignRight|ShowPrefix);
+  QLabel *rdcart_end_date_label=
+    new QLabel(rdcart_end_date_edit,tr("&End Date:"),this);
+  rdcart_end_date_label->setGeometry(260,86,85,21);
+  rdcart_end_date_label->setFont(labelFont());
+  rdcart_end_date_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
   rdcart_end_date_edit->hide();
   rdcart_end_date_label->hide();
 
   //
   // Cart Artist
   //
-  rdcart_controls.artist_edit=new QLineEdit(this,"rdcart_artist_edit");
+  rdcart_controls.artist_edit=new QLineEdit(this);
   rdcart_controls.artist_edit->setGeometry(135,84,480,21);
-  rdcart_controls.artist_edit->setFont(line_edit_font);
   rdcart_controls.artist_edit->setMaxLength(255);
-  QLabel *rdcart_artist_label=new QLabel(rdcart_controls.artist_edit,tr("&Artist:"),
-					 this,"rdcart_artist_label");
-  rdcart_artist_label->setGeometry(10,86,120,19);
-  rdcart_artist_label->setFont(button_font);
-  rdcart_artist_label->setAlignment(AlignRight|ShowPrefix);
+  QLabel *rdcart_artist_label=
+    new QLabel(rdcart_controls.artist_edit,tr("&Artist:"),this);
+  rdcart_artist_label->setGeometry(10,86,120,21);
+  rdcart_artist_label->setFont(labelFont());
+  rdcart_artist_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Cart Origination Year
   //
   QIntValidator *val=new QIntValidator(this);
   val->setBottom(1);
-  rdcart_controls.year_edit=new QLineEdit(this,"rdcart_year_edit");
+  rdcart_controls.year_edit=new QLineEdit(this);
   rdcart_controls.year_edit->setGeometry(135,110,50,21);
-  rdcart_controls.year_edit->setFont(line_edit_font);
   rdcart_controls.year_edit->setValidator(val);
   rdcart_controls.year_edit->setMaxLength(255);
-  QLabel *rdcart_year_label=new QLabel(rdcart_controls.year_edit,
-					     tr("&Year Released:"),this,
-					     "rdcart_year_label");
-  rdcart_year_label->setGeometry(10,112,120,19);
-  rdcart_year_label->setFont(button_font);
-  rdcart_year_label->setAlignment(AlignRight|ShowPrefix);
+  QLabel *rdcart_year_label=
+    new QLabel(rdcart_controls.year_edit,tr("&Year Released:"),this);
+  rdcart_year_label->setGeometry(10,112,120,21);
+  rdcart_year_label->setFont(labelFont());
+  rdcart_year_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Cart Usage Code
   //
-  rdcart_usage_box=new QComboBox(this,"rdcart_usage_box");
+  rdcart_usage_box=new QComboBox(this);
   rdcart_usage_box->setGeometry(270,110,150,21);
   if(lib_cart_list_edit!=0) {
     rdcart_usage_box->insertItem("");
@@ -341,22 +299,21 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   for(int i=0;i<(int)RDCart::UsageLast;i++) {
     rdcart_usage_box->insertItem(RDCart::usageText((RDCart::UsageCode)i));
   }
-  QLabel *label=
-    new QLabel(rdcart_usage_box,tr("U&sage:"),this,"rdcart_usage_label");
-  label->setGeometry(195,112,70,19);
-  label->setFont(button_font);
-  label->setAlignment(AlignRight|ShowPrefix);
-  rdcart_usage_edit=new QLineEdit(this,"rdcart_usage_edit");
+  QLabel *label=new QLabel(rdcart_usage_box,tr("U&sage:"),this);
+  label->setGeometry(195,112,70,21);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
+  rdcart_usage_edit=new QLineEdit(this);
   rdcart_usage_edit->setGeometry(270,110,150,21);
   rdcart_usage_edit->setReadOnly(true);
 
   //
   // Scheduler Codes
   //
-  QPushButton *sched_codes_button=new QPushButton(this,"sched_codes_button");
+  QPushButton *sched_codes_button=new QPushButton(this);
   sched_codes_button->setGeometry(470,106,150,28);
   sched_codes_button->setDefault(true);
-  sched_codes_button->setFont(button_font);
+  sched_codes_button->setFont(buttonFont());
   sched_codes_button->setText(tr("Scheduler Codes"));
   connect(sched_codes_button,SIGNAL(clicked()),this,SLOT(schedCodesData()));
  
@@ -365,150 +322,146 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   //
   rdcart_controls.song_id_edit=new QLineEdit(this);
   rdcart_controls.song_id_edit->setGeometry(135,135,240,21);
-  rdcart_controls.song_id_edit->setFont(line_edit_font);
   rdcart_controls.song_id_edit->setMaxLength(32);
   QLabel *rdcart_song_id_label=
     new QLabel(rdcart_controls.song_id_edit,tr("Song &ID:"),this);
   rdcart_song_id_label->setGeometry(10,135,120,21);
-  rdcart_song_id_label->setFont(button_font);
-  rdcart_song_id_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  rdcart_song_id_label->setFont(labelFont());
+  rdcart_song_id_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Beats per Minute
   //
   rdcart_controls.bpm_spin=new QSpinBox(this);
   rdcart_controls.bpm_spin->setGeometry(515,135,100,21);
-  rdcart_controls.bpm_spin->setFont(line_edit_font);
   rdcart_controls.bpm_spin->setRange(0,300);
   rdcart_controls.bpm_spin->setSpecialValueText(tr("Unknown"));
   QLabel *rdcart_bpm_label=
     new QLabel(rdcart_controls.bpm_spin,tr("&Beats per Minute:"),this);
   rdcart_bpm_label->setGeometry(390,135,120,21);
-  rdcart_bpm_label->setFont(button_font);
-  rdcart_bpm_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  rdcart_bpm_label->setFont(labelFont());
+  rdcart_bpm_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Cart Album
   //
-  rdcart_controls.album_edit=new QLineEdit(this,"rdcart_album_edit");
+  rdcart_controls.album_edit=new QLineEdit(this);
   rdcart_controls.album_edit->setGeometry(135,158,480,21);
-  rdcart_controls.album_edit->setFont(line_edit_font);
-  rdcart_controls.album_edit->setMaxLength(64);
-  QLabel *rdcart_album_label=new QLabel(rdcart_controls.album_edit,tr("Al&bum:"),this,
-				       "rdcart_album_label");
+  rdcart_controls.album_edit->setMaxLength(255);
+  QLabel *rdcart_album_label=
+    new QLabel(rdcart_controls.album_edit,tr("Al&bum:"),this);
   rdcart_album_label->setGeometry(10,158,120,21);
-  rdcart_album_label->setFont(button_font);
-  rdcart_album_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  rdcart_album_label->setFont(labelFont());
+  rdcart_album_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Cart Label
   // 
-  rdcart_controls.label_edit=new QLineEdit(this,"rdcart_label_edit");
+  rdcart_controls.label_edit=new QLineEdit(this);
   rdcart_controls.label_edit->setGeometry(135,182,480,21);
-  rdcart_controls.label_edit->setFont(line_edit_font);
   rdcart_controls.label_edit->setMaxLength(64);
-  QLabel *rdcart_label_label=new QLabel(rdcart_controls.label_edit,tr("Re&cord Label:"),
-					this,"rdcart_label_label");
+  QLabel *rdcart_label_label=
+    new QLabel(rdcart_controls.label_edit,tr("Re&cord Label:"),this);
   rdcart_label_label->setGeometry(10,182,120,21);
-  rdcart_label_label->setFont(button_font);
-  rdcart_label_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  rdcart_label_label->setFont(labelFont());
+  rdcart_label_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Cart Client
   //
-  rdcart_controls.client_edit=new QLineEdit(this,"rdcart_client_edit");
+  rdcart_controls.client_edit=new QLineEdit(this);
   rdcart_controls.client_edit->setGeometry(135,206,480,21);
-  rdcart_controls.client_edit->setFont(line_edit_font);
   rdcart_controls.client_edit->setMaxLength(64);
-  QLabel *rdcart_client_label=new QLabel(rdcart_controls.label_edit,tr("C&lient:"),this,
-				       "rdcart_client_label");
+  QLabel *rdcart_client_label=
+    new QLabel(rdcart_controls.label_edit,tr("C&lient:"),this);
   rdcart_client_label->setGeometry(10,206,120,21);
-  rdcart_client_label->setFont(button_font);
-  rdcart_client_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  rdcart_client_label->setFont(labelFont());
+  rdcart_client_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Cart Agency
   //
-  rdcart_controls.agency_edit=new QLineEdit(this,"rdcart_agency_edit");
+  rdcart_controls.agency_edit=new QLineEdit(this);
   rdcart_controls.agency_edit->setGeometry(135,230,480,21);
-  rdcart_controls.agency_edit->setFont(line_edit_font);
   rdcart_controls.agency_edit->setMaxLength(64);
-  QLabel *rdcart_agency_label=new QLabel(rdcart_controls.label_edit,tr("A&gency:"),this,
-				       "rdcart_agency_label");
+  QLabel *rdcart_agency_label=
+    new QLabel(rdcart_controls.label_edit,tr("A&gency:"),this);
   rdcart_agency_label->setGeometry(10,230,120,21);
-  rdcart_agency_label->setFont(button_font);
-  rdcart_agency_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  rdcart_agency_label->setFont(labelFont());
+  rdcart_agency_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Cart Publisher
   //
-  rdcart_controls.publisher_edit=new QLineEdit(this,"rdcart_publisher_edit");
+  rdcart_controls.publisher_edit=new QLineEdit(this);
   rdcart_controls.publisher_edit->setGeometry(135,254,480,21);
-  rdcart_controls.publisher_edit->setFont(line_edit_font);
   rdcart_controls.publisher_edit->setMaxLength(64);
-  QLabel *rdcart_publisher_label=new QLabel(rdcart_controls.label_edit,
-					    tr("&Publisher:"),this,
-					    "rdcart_publisher_label");
+  QLabel *rdcart_publisher_label=
+    new QLabel(rdcart_controls.label_edit,tr("&Publisher:"),this);
   rdcart_publisher_label->setGeometry(10,254,120,21);
-  rdcart_publisher_label->setFont(button_font);
-  rdcart_publisher_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  rdcart_publisher_label->setFont(labelFont());
+  rdcart_publisher_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Cart Composer
   //
-  rdcart_controls.composer_edit=new QLineEdit(this,"rdcart_composer_edit");
+  rdcart_controls.composer_edit=new QLineEdit(this);
   rdcart_controls.composer_edit->setGeometry(135,278,480,21);
-  rdcart_controls.composer_edit->setFont(line_edit_font);
   rdcart_controls.composer_edit->setMaxLength(64);
-  QLabel *rdcart_composer_label=new QLabel(rdcart_controls.label_edit,
-					   tr("Compos&er:"),this,
-					   "rdcart_composer_label");
+  QLabel *rdcart_composer_label=
+    new QLabel(rdcart_controls.label_edit,tr("Compos&er:"),this);
   rdcart_composer_label->setGeometry(10,278,120,21);
-  rdcart_composer_label->setFont(button_font);
-  rdcart_composer_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  rdcart_composer_label->setFont(labelFont());
+  rdcart_composer_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Cart Conductor
   //
-  rdcart_controls.conductor_edit=new QLineEdit(this,"rdcart_conductor_edit");
+  rdcart_controls.conductor_edit=new QLineEdit(this);
   rdcart_controls.conductor_edit->setGeometry(135,302,480,21);
-  rdcart_controls.conductor_edit->setFont(line_edit_font);
   rdcart_controls.conductor_edit->setMaxLength(255);
   QLabel *rdcart_conductor_label=
-    new QLabel(rdcart_controls.label_edit,tr("Cond&uctor:"),this,
-	       "rdcart_conductor_label");
+    new QLabel(rdcart_controls.label_edit,tr("Cond&uctor:"),this);
   rdcart_conductor_label->setGeometry(10,302,120,21);
-  rdcart_conductor_label->setFont(button_font);
-  rdcart_conductor_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  rdcart_conductor_label->setFont(labelFont());
+  rdcart_conductor_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
  
   //
   // Cart User Defined
   //
   rdcart_controls.user_defined_edit=new QLineEdit(this);
   rdcart_controls.user_defined_edit->setGeometry(135,325,480,21);
-  rdcart_controls.user_defined_edit->setFont(line_edit_font);
   rdcart_controls.user_defined_edit->setMaxLength(255);
   QLabel *rdcart_user_defined_label=
-    new QLabel(rdcart_controls.label_edit,tr("&User Defined:"),this,
-	       "rdcart_user_defined_label");
+    new QLabel(rdcart_controls.label_edit,tr("&User Defined:"),this);
   rdcart_user_defined_label->setGeometry(10,325,120,21);
-  rdcart_user_defined_label->setFont(button_font);
-  rdcart_user_defined_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  rdcart_user_defined_label->setFont(labelFont());
+  rdcart_user_defined_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
  
   //
   // Synchronous Scheduling Policy
   //
-  rdcart_syncronous_box=new QCheckBox(this,"rdcart_syncronous_box");
+  rdcart_syncronous_box=new QCheckBox(this);
   rdcart_syncronous_box->setGeometry(135,351,15,15);
   connect(rdcart_syncronous_box,SIGNAL(toggled(bool)),
 	  this,SLOT(asyncronousToggledData(bool)));
   rdcart_syncronous_box->hide();
-  QLabel *rdcart_syncronous_label=new QLabel(rdcart_syncronous_box,
-					    tr("Execute Asynchronously"),this,
-					    "rdcart_syncronous_label");
-  rdcart_syncronous_label->setGeometry(155,351,200,19);
-  rdcart_syncronous_label->setFont(button_font);
-  rdcart_syncronous_label->setAlignment(AlignLeft|ShowPrefix);
+  QLabel *rdcart_syncronous_label=
+    new QLabel(rdcart_syncronous_box,tr("Execute Asynchronously"),this);
+  rdcart_syncronous_label->setGeometry(155,348,200,21);
+  rdcart_syncronous_label->setFont(labelFont());
+  rdcart_syncronous_label->
+    setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
   rdcart_syncronous_label->hide();
 
   //
@@ -521,10 +474,12 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   rdcart_use_event_length_box->hide();
   QLabel *rdcart_use_event_length_label=
     new QLabel(rdcart_use_event_length_box,
-	       tr("Use Event Length for Now && Next Updates"),this);
-  rdcart_use_event_length_label->setGeometry(350,351,sizeHint().width()-350,19);
-  rdcart_use_event_length_label->setFont(button_font);
-  rdcart_use_event_length_label->setAlignment(AlignLeft|ShowPrefix);
+	       tr("Use RDLogManager Length for PAD Updates"),this);
+  //	       tr("Use Event Length for Now && Next Updates"),this);
+  rdcart_use_event_length_label->setGeometry(350,348,sizeHint().width()-350,21);
+  rdcart_use_event_length_label->setFont(labelFont());
+  rdcart_use_event_length_label->
+    setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
   rdcart_use_event_length_label->hide();
 
   //
@@ -539,26 +494,26 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   rdcart_cut_sched_edit->hide();
   QLabel *rdcart_cut_sched_label=
     new QLabel(rdcart_cut_sched_box,tr("Schedule Cuts")+":",this);
-  rdcart_cut_sched_label->setGeometry(10,348,120,19);
-  rdcart_cut_sched_label->setFont(button_font);
-  rdcart_cut_sched_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  rdcart_cut_sched_label->setGeometry(10,348,120,21);
+  rdcart_cut_sched_label->setFont(labelFont());
+  rdcart_cut_sched_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Notes Button
   //
-  rdcart_notes_button=new QPushButton(this,"rdcart_notes_button");
-  //  rdcart_notes_button->setGeometry(360,304,80,50);
+  rdcart_notes_button=new QPushButton(this);
   rdcart_notes_button->setGeometry(10,sizeHint().height()-60,80,50);
-  rdcart_notes_button->setFont(button_font);
+  rdcart_notes_button->setFont(buttonFont());
   rdcart_notes_button->setText(tr("&Edit\nNotes"));
   connect(rdcart_notes_button,SIGNAL(clicked()),this,SLOT(notesData()));
 
   //
   //  Script Button
   //
-  QPushButton *script_button=new QPushButton(this,"script_button");
+  QPushButton *script_button=new QPushButton(this);
   script_button->setGeometry(450,304,80,50);
-  script_button->setFont(button_font);
+  script_button->setFont(buttonFont());
   script_button->setText(tr("&Edit\nScript"));
   connect(script_button,SIGNAL(clicked()),this,SLOT(scriptData()));
   script_button->hide();
@@ -583,7 +538,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
 	break;
 	
       case RDCart::Macro:
-	rdcart_macro_cart=new MacroCart(rdcart_cart,this,"rdcart_macro_cart");
+	rdcart_macro_cart=new MacroCart(rdcart_cart,this);
 	rdcart_macro_cart->
 	  setGeometry(0,378,rdcart_macro_cart->sizeHint().width(),
 		      rdcart_macro_cart->sizeHint().height());
@@ -606,27 +561,27 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
   //
   //  Ok Button
   //
-  QPushButton *ok_button=new QPushButton(this,"ok_button");
+  QPushButton *ok_button=new QPushButton(this);
   if(lib_cart_list_edit==NULL) 
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   else
     ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60-270,80,50);
   ok_button->setDefault(true);
-  ok_button->setFont(button_font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
   //
   //  Cancel Button
   //
-  QPushButton *cancel_button=new QPushButton(this,"cancel_button");
+  QPushButton *cancel_button=new QPushButton(this);
   if(lib_cart_list_edit==NULL) 
   cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
 			     80,50);
   else 
     cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60-270,
 			     80,50);
-  cancel_button->setFont(button_font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -779,7 +734,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,bool profile_rip,
       rdcart_cut_sched_edit->show();
     }
   }
-  if(rdcart_cart->type()==RDCart::Macro) {
+  if((rdcart_cart==NULL)||(rdcart_cart->type()==RDCart::Macro)) {
     rdcart_cut_sched_box->hide();
     rdcart_cut_sched_label->hide();
   }
@@ -830,7 +785,7 @@ void EditCart::lengthChangedData(unsigned len)
 
 void EditCart::okData()
 {
-  QListViewItemIterator *it;
+  Q3ListViewItemIterator *it;
   RDCart *rdcart_cart_medit;
   RDSystem *system;
   QString sql;
@@ -950,13 +905,13 @@ void EditCart::okData()
     }
   }
   else {  // Multi Edit
-    it=new QListViewItemIterator(lib_cart_list_edit);
+    it=new Q3ListViewItemIterator(lib_cart_list_edit);
     while(it->current()) {
       if(it->current()->isSelected()) {  
         RDListViewItem *item=(RDListViewItem *)it->current();
-        if(item->text(21).isEmpty()) {
+        if(item->text(MainWidget::OwnedBy).isEmpty()) {
  
-          rdcart_cart_medit=new RDCart(item->text(1).toUInt());
+          rdcart_cart_medit=new RDCart(item->text(MainWidget::Cart).toUInt());
 	  
           if(!rdcart_group_box->currentText().stripWhiteSpace().isEmpty()) {
 	    rdcart_cart_medit->setGroupName(rdcart_group_box->currentText());
@@ -964,7 +919,9 @@ void EditCart::okData()
           if(!rdcart_controls.title_edit->text().stripWhiteSpace().isEmpty()) {
             rdcart_cart_medit->setTitle(rdcart_controls.title_edit->text());
 	  }
-	  rdcart_cart_medit->setYear(rdcart_controls.year_edit->text().toInt());
+          if(rdcart_controls.year_edit->text().toInt()) {
+            rdcart_cart_medit->setYear(rdcart_controls.year_edit->text().toInt());
+          }
           if(!rdcart_controls.artist_edit->text().stripWhiteSpace().isEmpty()) {
             rdcart_cart_medit->setArtist(rdcart_controls.artist_edit->text());
 	  }
@@ -1108,12 +1065,13 @@ bool EditCart::ValidateLengths()
 void EditCart::schedCodesData()
 {
   if(lib_cart_list_edit==NULL) {
-    EditSchedulerCodes *dialog=new EditSchedulerCodes(&sched_codes,NULL,this,"dialog");
+    EditSchedulerCodes *dialog=new EditSchedulerCodes(&sched_codes,NULL,this);
     dialog->exec();
     delete dialog;
     }
   else  {
-    EditSchedulerCodes *dialog=new EditSchedulerCodes(&add_codes,&remove_codes,this,"dialog");
+    EditSchedulerCodes *dialog=
+      new EditSchedulerCodes(&add_codes,&remove_codes,this);
     dialog->exec();
     delete dialog;
     }
@@ -1123,7 +1081,7 @@ void EditCart::schedCodesData()
 void EditCart::PopulateGroupList()
 {
   QString sql=QString("select GROUP_NAME from USER_PERMS where ")+
-    "USER_NAME=\""+RDEscapeString(lib_user->name())+"\" "+
+    "USER_NAME=\""+RDEscapeString(rda->user()->name())+"\" "+
     "order by GROUP_NAME";
 
   RDSqlQuery *q=new RDSqlQuery(sql);
