@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell Macro
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_macro.cpp,v 1.11.8.2 2013/12/23 22:04:02 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,70 +18,47 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
 #include <qpushbutton.h>
-#include <qlabel.h>
-#include <qsqldatabase.h>
 
-#include <rdtextvalidator.h>
+#include "edit_macro.h"
 
-#include <edit_macro.h>
-
-
-EditMacro::EditMacro(RDMacro *cmd,bool highlight,
-		     QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+EditMacro::EditMacro(RDMacro *cmd,bool highlight,QWidget *parent)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-
-  //
-  // Generate Fonts
-  //
-  QFont button_font("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-
-  setCaption(tr("Edit Macro"));
-
-  //
-  // Text Validator
-  //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
   // Macro
   //
   edit_macro=cmd;
 
-  edit_macro_edit=new QLineEdit(this,"edit_macro_edit");
+  edit_macro_edit=new QLineEdit(this);
   edit_macro_edit->setMaxLength(RD_RML_MAX_LENGTH-1);
-  edit_macro_edit->setValidator(validator);
 
   //
   //  Ok Button
   //
-  edit_ok_button=new QPushButton(this,"ok_button");
+  edit_ok_button=new QPushButton(this);
   edit_ok_button->setDefault(true);
-  edit_ok_button->setFont(button_font);
+  edit_ok_button->setFont(buttonFont());
   edit_ok_button->setText(tr("&OK"));
   connect(edit_ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
   //
   //  Cancel Button
   //
-  edit_cancel_button=new QPushButton(this,"cancel_button");
-  edit_cancel_button->setFont(button_font);
+  edit_cancel_button=new QPushButton(this);
+  edit_cancel_button->setFont(buttonFont());
   edit_cancel_button->setText(tr("&Cancel"));
   connect(edit_cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
-  char cmdstr[RD_RML_MAX_LENGTH];
-  edit_macro->generateString(cmdstr,RD_RML_MAX_LENGTH);
-  edit_macro_edit->setText(cmdstr);
+  edit_macro_edit->setText(edit_macro->toString());
   if(highlight) {
     edit_macro_edit->selectAll();
   }
@@ -104,8 +79,7 @@ QSizePolicy EditMacro::sizePolicy() const
 
 void EditMacro::okData()
 {
-  edit_macro->parseString((const char *)edit_macro_edit->text(),
-			  edit_macro_edit->text().length());
+  *edit_macro=RDMacro::fromString(edit_macro_edit->text());
   done(0);
 }
 
