@@ -2,9 +2,7 @@
 //
 // Add a Rivendell RDCatch Event
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: add_meta.h,v 1.6 2010/07/29 19:32:37 cvs Exp $
+//   (C) Copyright 2018-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,21 +21,15 @@
 #ifndef ADD_META_H
 #define ADD_META_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
-#include <qlineedit.h>
-#include <qdatetimeedit.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
-#include <qspinbox.h>
 #include <qlabel.h>
 
+#include <rddialog.h>
 
-class AddMeta : public QDialog
+class AddMeta : public RDDialog
 {
   Q_OBJECT
  public:
-  AddMeta(QWidget *parent=0,const char *name=0);
+  AddMeta(QWidget *parent=0);
   ~AddMeta();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
