@@ -2,7 +2,7 @@
 //
 // Add a Rivendell Log Manager Event
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,17 +21,12 @@
 #ifndef ADD_EVENT_H
 #define ADD_EVENT_H
 
-#include <qdialog.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qpixmap.h>
-#include <qcheckbox.h>
-#include <qsqldatabase.h>
 #include <qlineedit.h>
 
-#include <rdevent.h>
+#include <rddialog.h>
 
-class AddEvent : public QDialog
+
+class AddEvent : public RDDialog
 {
   Q_OBJECT
  public:
